@@ -221,8 +221,15 @@ int Controller::gui_comm_callback(char *buf, int bytes) {
 			incomplete+=s;
 			return 0;
 		}
-		incomplete+=s.substr(0,endline);
-		theOneController->takeLine(incomplete); //is now complete
+		
+		//strip a \r\n or a \n
+		if(endline>0 && s[endline-1]=='\r')
+			incomplete+=s.substr(0,endline-1);
+		else
+			incomplete+=s.substr(0,endline);
+		
+		//is now complete
+		theOneController->takeLine(incomplete); 
 		incomplete.erase();
 		s=s.substr(endline+1);
 	}
@@ -245,8 +252,14 @@ int Controller::console_callback(char *buf, int bytes) {
 			incomplete+=s;
 			return 0;
 		}
-		incomplete+=s.substr(0,endline);
-		//is now complete:
+
+		//strip a \r\n or a \n
+		if(endline>0 && s[endline-1]=='\r')
+			incomplete+=s.substr(0,endline-1);
+		else
+			incomplete+=s.substr(0,endline);
+		
+		//is now complete
 		if(wireless->isConnected(theOneController->gui_comm->sock))
 			erouter->postEvent(new TextMsgEvent(incomplete));
 		else
@@ -439,8 +452,8 @@ bool Controller::chkCmdStack() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.35 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.36 $
  * $State: Exp $
- * $Date: 2004/01/21 03:52:39 $
+ * $Date: 2004/03/01 21:16:48 $
  */
