@@ -23,11 +23,11 @@
  *	- '<tt>!prev</tt>' - calls ControlBase::doPrevItem() of the current control
  *	- '<tt>!select</tt>' - calls ControlBase::doSelect() of the current control
  *	- '<tt>!cancel</tt>' - calls ControlBase::doCancel() of the current control
- *	- '<tt>!msg </tt><i>text</i>' - broadcasts <i>text</i> as a TextMsgEvent
+ *	- '<tt>!msg </tt><i>text</i>' - sends <i>text</i> out as a TextMsgEvent; also note that any text entered on the console port while a GUI is also connected will also be sent as a TextMsgEvent, without needing the !input.
  *  - '<tt>!root </tt><i>text</i>' - calls ControlBase::takeInput(<i>text</i>) on the root control
  *  - '<tt>!hello</tt>' - responds with '<tt>hello\n</tt><i>count</i>' where <i>count</i> is the number of times '<tt>!hello</tt>' has been sent.  Good for detecting first connection after boot vs. a reconnect.
  *	- '<tt>!hilight</tt> [<i>n1</i> [<i>n2</i> [...]]]' - hilights zero, one, or more items in the menu
- *	- '<tt>!input </tt><i>text</i>' - calls ControlBase::takeInput(<i>text</i>) on the currently hilighted control(s)
+ *	- '<tt>!input </tt><i>text</i>' - calls ControlBase::takeInput(text) on the currently hilighted control(s)
  *	- any text not beginning with '!' - sent to ControlBase::takeInput() of the current control
  *
  *  In return, to send the menus to the GUI, the following messages are sent: (newlines are required where shown)
@@ -82,6 +82,13 @@
  *  Model-View-Controller architecture, almost by necessity. (HCI
  *  happens to be my double major when I was an undergrad ;)
  *    
+ *  Also, the Controller is responsible for sending out TextMsgEvents
+ *  from user input it receives - either a !msg command from the
+ *  console or GUI, or <i>any text at all</i> which is received on the
+ *  console if there is already a GUI connected.
+ *
+ *  These TextMsgEvents are always status events, and the duration
+ *  field is always 0.
  */
 class Controller : public BehaviorBase, public EventTrapper {
 public:
@@ -203,10 +210,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.27 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.28 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:10 $
+ * $Date: 2004/02/09 22:45:28 $
  */
 
 #endif
