@@ -46,6 +46,7 @@ public:
 
 	//! destructor
 	virtual ~BehaviorSwitchControlBase() {
+		//cout << "~BehaviorSwitchControlBase(): " << getName() << endl;
 		if(mybeh!=NULL)
 			stop();
 		if(behgrp!=NULL) {
@@ -78,9 +79,13 @@ public:
 
 	//! adds a status to the name: - if in memory, # if running
 	virtual std::string getName() const {
+		if(mybeh==NULL)
+			return ControlBase::getName();
 		return (mybeh->isActive()?'#':'-')+mybeh->getName();
 	}
 	virtual std::string getDescription() const {
+		if(mybeh==NULL)
+			return ControlBase::getDescription();
 		return mybeh->getDescription();
 	}
 	
@@ -258,10 +263,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2003/12/13 05:00:25 $
+ * $Date: 2004/02/18 21:11:25 $
  */
 
 #endif
