@@ -11,20 +11,29 @@
 #include <vector>
 
 //! Base class for all items in the Controller hierarchy.
-/*! These are similar to behaviors in that they can do processing and are told
- *  when to start and stop.
+/*! These are similar to behaviors in that they can do processing and
+ *  are told when to start and stop.
  *
- *  However, the important difference is that these have to follow a much
- *  tighter set of guidelines for a more refined purpose - user interface.
- *  Controls do not directly receive events - the Controller will process events
- *  for them and call the appropriate functions at the appropriate times.
- *  Controls are expected to fit into a heirarchical scheme, where each control
- *  (except the root) has a parent which created it, and may return its own
- *  children where appropriate.
+ *  However, the important difference is that these have to follow a
+ *  much tighter set of guidelines for a more refined purpose - user
+ *  interface.  Controls do not directly receive events - the
+ *  Controller will process events for them and call the appropriate
+ *  functions at the appropriate times.  Controls are expected to fit
+ *  into a heirarchical scheme, where each control (except the root)
+ *  has a parent which created it, and may return its own children
+ *  where appropriate.
  *
- *  This base class will do most of the work of maintain submenus for you, and
- *  will call appropriate virtual functions which you can override.  Controls
- *  generally live in Behaviors/Controls/ as the Controller itself is a
+ *  Controls can be very powerful, and a class can be both a behavior
+ *  and a control.  This allows integrated user interface to
+ *  controlling a complex behavior.  Some controls may simply need
+ *  EventListener access instead to perform a few tricks.  Mix and
+ *  match as you see fit.  (multiple inheritance can be nice if it's
+ *  planned for, as these have been)
+ *
+ *  This base class will do most of the work of maintaining submenus
+ *  for you, and will call appropriate virtual functions which you are
+ *  expected to override.  Controls generally live in
+ *  <tt>Behaviors/Controls/</tt> as the Controller itself is a
  *  behavior, and these controls merely its tools.
  *
  *  The ControlBase pointers which are returned at various points are the
@@ -33,16 +42,16 @@
  *
  *  GUI Theory: \n
  *  There are 3 levels to the user interface.
- *  -# Robot/Local: Uses the LEDs and sounds for immediate feedback.  No external resources needed
+ *  -# Robot/Local: Uses the buttons for input, and LEDs and sounds for immediate feedback.  No external resources needed
  *  -# Text: Uses a console to display/request information.
- *  -# GUI: Uses a graphical interface on an external screen
+ *  -# GUI: Uses a graphical interface on a desktop machine
  *
  *  Obviously, higher levels require more technological resources, which also
  *  means there's more to go wrong and debug.  However, another important
  *  distinction between the first level and the others is that the first level
  *  does not require the user to lose direct contact with the robot.  Requiring
  *  the user to move back and forth from robot to computer can be much more
- *  frustrating than decoding LED signals or press head buttons.  There are
+ *  frustrating than decoding LED signals or press head buttons.  There are also
  *  safety issues when triggering behaviors remotely if the robot is out of
  *  immediate reach.  But of course, having a GUI and text output is extremely
  *  valuable in terms of ease of use and efficiency.
@@ -57,6 +66,8 @@
 class ControlBase {
 public:
 	
+	//! @name Constructors/Destructors
+
 	ControlBase() : name("(null name)"), description(), hilights(), options(), doRewrite(false), display_id(MotionManager::invalid_MC_ID), gui_comm(NULL) {} //!< Contructor
 	ControlBase(const std::string& n) : name(n), description(), hilights(), options(), doRewrite(false), display_id(MotionManager::invalid_MC_ID), gui_comm(NULL) {} //!< Contructor, initializes with a name
 	ControlBase(const std::string& n, const std::string& d) : name(n), description(d), hilights(), options(), doRewrite(false), display_id(MotionManager::invalid_MC_ID), gui_comm(NULL) {} //!< Contructor, initializes with a name
@@ -64,9 +75,12 @@ public:
 	//! Destructor
 	virtual ~ControlBase() {
 		//		deactivate();
+		//cout << "~ControlBase(): " << name << endl;
 		clearSlots();
 	}
 
+	//@}
+
 	//! You probably want to override some of these, call the ControlBase functions from your code if you want default sound effects (or look in Config::controller_config).
 	//! @name Controller Functions
 
@@ -76,29 +90,44 @@ public:
 	 *  @return a ControlBase pointer.  Return: @li @a this if the control should stay active (if it's not a one-shot command) @li @c NULL to return to parent @li other address to spawn a child control*/
 	virtual ControlBase * activate(MotionManager::MC_ID disp_id, Socket * gui);
 	virtual void pause();      //!< called when a control is being overriden by a child, or the control system is deactivating (e-stop being turned off)
-	virtual void refresh();    //!< called when the child has died and this control should refresh its display, or some other event (such as the user pressing the refresh button) has happened to cause a refresh to be needed
+	virtual void refresh();    //!< called when the child has deactivated and this control should refresh its display, or some other event (such as the user pressing the refresh button) has happened to cause a refresh to be needed
 	virtual void deactivate(); //!< called when this control is being popped from the control stack
 
-	virtual ControlBase * doSelect();   //!< when the user has trigger an "open selection" - default is to return the hilighted control
-	virtual ControlBase * doNextItem(); //!< when the user wants to increment the control - default is to return the first non-null slot after the last hilight
-	virtual ControlBase * doPrevItem(); //!< when the user wants to decrement the control - default is to return the last non-null slot before the first hilight
-	virtual ControlBase * doCancel();   //!< when the user wants to cancel - you should almost always return NULL now unless you need to confirm something (e.g. "Save changes?")
-	virtual ControlBase * doReadStdIn(const std::string& prompt=std::string()); //!< prompt the user for text input on the current input device (cin, tekkotsu console (sout), or GUI)
-	virtual ControlBase * takeInput(const std::string& msg); //!< called when the user has supplied a text string (may not have been prompted by doReadStdIn()!)
-	virtual bool validInput(const std::string& msg); //!< may be called before takeInput to verify this Control can make sense of msg
+	//! when the user has trigger an "open selection" - default is to return the hilighted control*/
+	/*! The value which is returned is then activate()ed and pushed on the Controller's stack*/
+	virtual ControlBase * doSelect();
+	//! when the user wants to increment the control - default is to hilight the first non-null slot after the last hilight, and return @c this
+	/*! The value which is returned is then activate()ed and pushed on the Controller's stack, so you probably want to return @c this */
+	virtual ControlBase * doNextItem();
+	//! when the user wants to decrement the control - default is to hilight the last non-null slot before the first hilight, and return @c this
+	/*! The value which is returned is then activate()ed and pushed on the Controller's stack, so you probably want to return @c this */
+	virtual ControlBase * doPrevItem();
+	//! when the user wants to cancel - you should almost always return NULL now unless you need to override the cancel in order to confirm something (e.g. "Save changes?")
+	/*! The value which is returned is then activate()ed and pushed on the Controller's stack, you probably want to return @c NULL */
+	virtual ControlBase * doCancel();
+	//! prompt the user for text input on the current input device (cin, tekkotsu console (sout), or GUI)
+	/*! The value which is returned is then activate()ed and pushed on the Controller's stack, so you probably want to return @c this */
+	virtual ControlBase * doReadStdIn(const std::string& prompt=std::string());
+	//! called when the user has supplied a text string (may or may not have been prompted by doReadStdIn()!  May not even be active yet - the user can direct the same input to a set of hilighted menus)
+	/*! The value which is returned is then activate()ed and pushed on the Controller's stack*/
+	virtual ControlBase * takeInput(const std::string& msg); 
+	//! may be called before takeInput to verify this Control can make sense of msg
+	virtual bool validInput(const std::string& msg); 
 	//@}
 	
+	//! @name Accessors
+
 	virtual ControlBase& setName(const std::string& n) { name=n; return *this; } //!< sets the name of the control
 	virtual std::string getName() const { return name; } //!< returns the name of the control
 
 	virtual ControlBase& setDescription(const std::string d) { description=d; return *this; } //!< sets the description of the control
 	virtual std::string getDescription() const { return description; } //!< returns a short description of what the control does
 
-	const std::vector<ControlBase*>& getSlots() const { return options; } //!< returns the vector of controls
+	const std::vector<ControlBase*>& getSlots() const { return options; } //!< returns the vector of sub-controls
 	std::string getSlotName(unsigned int i) const; //!< returns the string that will appear in slot @a i
 	unsigned int slotsSize() const { return options.size(); } //!< returns the number of options available
-	void setSlot(unsigned int i,ControlBase* o); //!< sets @a i'th element of ::options to @a o
-	void pushSlot(ControlBase* o); //!< sets next unused element of ::options to @a o
+	void setSlot(unsigned int i,ControlBase* o); //!< sets @a i'th element of #options to @a o
+	void pushSlot(ControlBase* o); //!< sets next unused element of #options to @a o
 	void clearSlots(); //!< deletes each slot item and clears the slots
 
 	virtual const std::vector<unsigned int>& getHilights() const { return hilights; } //!< returns a vector of the indicies of hilighted slots
@@ -108,6 +137,8 @@ public:
 	virtual MotionManager::MC_ID getDisplay() { return display_id; } //!< returns display being used
 	virtual ControlBase& setDisplay(MotionManager::MC_ID d) { display_id=d; return *this; } //!< sets display to use
 
+	//@}
+
 protected:
 		
 	//! clears the display (if use_VT100 is on)
@@ -137,9 +168,9 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.17 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2004/01/08 22:39:53 $
+ * $Date: 2004/02/18 21:11:25 $
  */
 #endif
