@@ -88,11 +88,14 @@ WalkCalibration::WalkCalibration()
 	help->pushSlot(new NullControl(""));
 	help->pushSlot(new NullControl("Enter angular"));
 	help->pushSlot(new NullControl("measurements in"));
-	help->pushSlot(new NullControl("degrees.  You will"));
-	help->pushSlot(new NullControl("almost always enter"));
+	help->pushSlot(new NullControl("degrees.  Enter"));
+	help->pushSlot(new NullControl("distances as "));
+	help->pushSlot(new NullControl("centimeters."));
+	help->pushSlot(new NullControl(""));
+	help->pushSlot(new NullControl("You will almost"));
+	help->pushSlot(new NullControl("always enter"));
 	help->pushSlot(new NullControl("positive values for"));
 	help->pushSlot(new NullControl("all measurements."));
-	help->pushSlot(new NullControl(""));
 	help->pushSlot(new NullControl("Enter negative"));
 	help->pushSlot(new NullControl("values only when"));
 	help->pushSlot(new NullControl("using cartesian"));
@@ -864,7 +867,7 @@ void WalkCalibration::err(const std::string& str) {
 		std::vector<std::string> errmsg;
 		errmsg.push_back("Error");
 		errmsg.push_back(str);
-		serr->printf(str.c_str());
+		serr->printf("%s\n",str.c_str());
 		Controller::loadGUI("org.tekkotsu.mon.ControllerErr","msg",0,errmsg);
 		sndman->PlayFile(config->controller.error_snd);
 		return;
@@ -909,9 +912,9 @@ void WalkCalibration::addSample(std::vector<float*>& dat, float x, float y, floa
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/01/19 22:03:58 $
+ * $Date: 2004/03/01 21:17:08 $
  */
 
