@@ -7,26 +7,30 @@
 #include <string>
 
 //! The basis of events passed around the high level system
-/*! Contains the list of 'known' event generators in EventGeneratorID_t
- *  and EventGeneratorNames[].  If you want to make a new generator, all
- *  you have to do is add a new entry to the ID list (EventGeneratorID_t)
- *  and then put it's name in the EventGeneratorNames[] array.
+/*! Contains the list of 'known' event generators in #EventGeneratorID_t
+ *  and #EventGeneratorNames[].  If you want to make a new generator, all
+ *  you have to do is add a new entry to the ID list (#EventGeneratorID_t)
+ *  and then put its name in the #EventGeneratorNames[] array.
  *
  *  Alternatively, there is an 'unlicensed spectrum' available under
- *  the unknownEGID.  You can send out events from that generator just
+ *  the #unknownEGID.  You can send out events from that generator just
  *  like any other, but it should only be used for quick tests and hacking
  *  around...
  *
- *  The SourceID is generator specific.  A SID of @a i from the button
- *  generator will refer to a particular button, whereas a SID from vision
- *  refers to seeing a particular object.  These SIDs are usually defined
- *  in the generators themselves.  See the EventGeneratorID_t list for
- *  links to the generators.
+ *  The #sourceID (just an unsigned int) is generator specific.  A SID
+ *  of @a i from the button generator (#buttonEGID) will refer to a
+ *  particular button, whereas a SID from a vision detector (say
+ *  #visObjEGID) refers to seeing a particular object.  These SIDs are
+ *  usually defined in the generators themselves.
  *
- *  The duration field is also generator specific - some may refer to
- *  the time since the last activation event (e.g. button events) where 
- *  as others refer to time since last status (e.g. sensors updates)
+ *  The #duration field is also generator specific - some may refer to
+ *  the time since the last activation event (e.g. button events)
+ *  where as others refer to time since last status (e.g. sensors
+ *  updates)
  *
+ *  The #EventGeneratorID_t list should contain links to the
+ *  generators' documentation, or will directly give information about
+ *  what to expect in events from that generator.
  */
 class EventBase : public LoadSave {
  public:
@@ -37,38 +41,38 @@ class EventBase : public LoadSave {
 	enum EventGeneratorID_t {
 		unknownEGID=0,    //!< default EGID, used if you forget to set it, probably not a good idea to use this for anything except errors or testing quick hacks
 		aiEGID,           //!< not being used, yet (might use this when AI makes decisions?)
-		audioEGID,        //!< Sends an event when a sound starts/ends playback, status events as chained sounds end
-		buttonEGID,       //!< Sends activate event for button down, deactivate for button up.  Status events only for when pressure sensitive buttons' reading changes. (on sensorEGID updates); see ButtonSourceID::ButtonSourceID_t
-		erouterEGID,      //!< Sends activate event on first listener, deactivate on last listener, and status on other listener changes.; source id is the generator ID affected
-		estopEGID,        //!< Sends an event when the estop is turned on or off
-		locomotionEGID,   //!< Sends events regarding transportation in the world; you can/should assume these will all be LocomotionEvent classes
-		motmanEGID,       //!< Sends events when a MotionCommand is added or removed, source is is the MC_ID
+		audioEGID,        //!< Sends an event when a sound starts/ends playback, status events as chained sounds end; SID is SoundManager::Play_ID; duration is playtime
+		buttonEGID,       //!< Sends activate event for button down, deactivate for button up.  Status events only for when pressure sensitive buttons' reading changes. (on sensorEGID updates); SIDs are from ButtonOffset_t in the namespace of the target model (e.g. ERS210Info::ButtonOffset_t); duration is button down time
+		erouterEGID,      //!< Sends activate event on first listener, deactivate on last listener, and status on other listener changes.; SID is the generator ID affected (NOT IMPLEMENTED YET)
+		estopEGID,        //!< Sends an event when the estop is turned on or off; SID is the MotionManager::MC_ID of the EmergencyStopMC; duration is length of estop activation
+		locomotionEGID,   //!< Sends events regarding transportation in the world; you can/should assume these will all be LocomotionEvent classes; SID is MotionManager::MC_ID of posting MotionCommand; duration is the time since last velocity change of that MC. (You could generate these for things other than walking...)
+		motmanEGID,       //!< Sends events when a MotionCommand is added or removed, SID is is the MotionManager::MC_ID, duration is always 0
 		powerEGID,        //!< Sends events for low power warnings, temperature, etc. see PowerSourceID::PowerSourceID_t
 		sensorEGID,       //!< Sends a status event when new sensor readings are available. see SensorSourceID::SensorSourceID_t
-		stateMachineEGID, //!< Sends an event upon entering and leaving a StateNode.
-    textmsgEGID,      //!< Sends events when a text msg is received on console
-		timerEGID,        //!< Sends timer events; you set timers explicitly, you don't have to listen as well. (See EventRouter::setTimer()) There's no cross-talk, only the listener which requested the timer will receive it.
-		visOFbkEGID,      //!< Sends a DataEvent<OFbkImageVectorData> for every camera image received from the system
-		visRawCameraEGID, //!< Sends a FilterBankEvent when new raw camera images are available
-		visInterleaveEGID,//!< Sends a FilterBankEvent when new interleaved images are available
-		visJPEGEGID,      //!< Sends a FilterBankEvent when JPEG compressed images are available
-		visSegmentEGID,   //!< Sends a FilterBankEvent when color segmentated images are available
-		visRLEEGID,       //!< Sends a FilterBankEvent when RLE encoded color segmentated images are available
-		visRegionEGID,    //!< Sends a FilterBankEvent when color regions are available
-		visObjEGID,       //!< Sends VisionObjectEvents for objects detected in camera images
+		stateMachineEGID, //!< Sends an event upon entering and leaving a StateNode; SID is pointer to the StateNode; duration is always 0
+    textmsgEGID,      //!< Sends status events when a text msg is received on console; generated by the Controller, SID is always -1; durations is always 0 (see Controller for more information)
+		timerEGID,        //!< Sends timer events; you set timers explicitly, you don't have to listen as well. (See EventRouter::addTimer()) There's no cross-talk, only the listener which requested the timer will receive it; SID is whatever you requested it to be; duration is the time (since boot, in ms) that the timer was supposed to go off; these are always status
+		visOFbkEGID,      //!< Sends a DataEvent <OFbkImageVectorData> for every camera image received from the system; SID and duration are always 0 (This is generated by the MainObj instantiation of MMCombo)
+		visRawCameraEGID, //!< Sends a FilterBankEvent when new raw camera images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
+		visInterleaveEGID,//!< Sends a FilterBankEvent when new interleaved images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
+		visJPEGEGID,      //!< Sends a FilterBankEvent when JPEG compressed images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
+		visSegmentEGID,   //!< Sends a SegmentedColorFilterBankEvent when color segmentated images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
+		visRLEEGID,       //!< Sends a SegmentedColorFilterBankEvent when RLE encoded color segmentated images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
+		visRegionEGID,    //!< Sends a SegmentedColorFilterBankEvent when color regions are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
+		visObjEGID,       //!< Sends VisionObjectEvents for objects detected in camera images; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
 		wmVarEGID,        //!< Sends an event when a watched memory is changed; source id is pointer to WMEntry
 		worldModelEGID,   //!< not being used, yet (for when objects are detected/lost?)
 		numEGIDs          //!< the number of generators available
 	};
 
-	//! Holds string versions of each of the generator's names, handy for debugging so you can output the events as readable strings
+	//! Holds string versions of each of the generator's names, handy for debugging so you can output the events as readable strings (you'll find this in EventBase.cc since it can't go in the header or we get multiply-defined errors during linking)
 	static const char* const EventGeneratorNames[numEGIDs];
 	
 	//! an event type id is used to denote whether it's the first in a sequence (button down), in a sequence (button still down), or last (button up)
 	enum EventTypeID_t {
-		activateETID,   //!< e.g. button down
-		statusETID,     //!< e.g. button still down
-		deactivateETID, //!< e.g. button up
+		activateETID,   //!< Start of an event sequence, e.g. button down
+		statusETID,     //!< Indicates a value has changed, e.g. new sensor readings
+		deactivateETID, //!< Last of a series of events, e.g. button up
 		numETIDs        //!< the number of different event types
 	};
 
@@ -85,8 +89,8 @@ class EventBase : public LoadSave {
 	virtual const std::string& getName() const { return stim_id; } //!< gets the name of the event - useful for debugging, outputs
 	virtual EventBase& setName(const std::string& n) { nameisgen=false; stim_id=n; return *this; } //!< sets name to a given string, prevents overwriting by generated names
 
-	virtual float getMagnitude() const { return magnitude; } //!< gets "strength" of event - you might have useful values... used by AI
-	virtual EventBase& setMagnitude(float m) { magnitude=m; return *this; }//!< sets "strength" of event - but you might have useful values... used by AI
+	virtual float getMagnitude() const { return magnitude; } //!< gets "strength" of event - by default 1 for activate and status events, 0 for deactivate events
+	virtual EventBase& setMagnitude(float m) { magnitude=m; return *this; }//!< sets "strength" of event - you may want to override the default values (see getMagnitude())
 
 	virtual unsigned int getTimeStamp() const { return timestamp; } //!< time event was created
 
@@ -99,8 +103,8 @@ class EventBase : public LoadSave {
 	virtual EventTypeID_t getTypeID() const { return typeID; } /*!< @brief gets the type ID @see EventTypeID_t */
 	virtual EventBase& setTypeID(EventTypeID_t tid) { typeID=tid; genName(); return *this; } /*!< @brief sets the type ID @see EventTypeID_t */
 
-	virtual unsigned int getDuration() const { return duration; } /*!< @brief OPTIONAL gets the time since the beginning of this sequence (the timestamp of the activate event) @see duration */
-	virtual EventBase& setDuration(unsigned int d) { duration = d; return *this; }/*!< @brief OPTIONAL gets the time since the beginning of this sequence (the timestamp of the activate event) @see duration */
+	virtual unsigned int getDuration() const { return duration; } /*!< @brief gets the time since the beginning of this sequence (the timestamp of the activate event) @see duration */
+	virtual EventBase& setDuration(unsigned int d) { duration = d; return *this; }/*!< @brief sets the time since the beginning of this sequence (the timestamp of the activate event) @see duration */
 
 	virtual const std::string& resetName() { nameisgen=true; genName(); return stim_id; } //!< resets name to generated form, overwriting any previous name
 	virtual bool isCustomName() const { return !nameisgen; } //!< returns true if not using the generated name
@@ -140,8 +144,10 @@ class EventBase : public LoadSave {
 													* Source IDs are defined by the generator that made it.  This should
 													* give authors flexibility to design their modules without having to
 													* worry about ID space collision */
-	unsigned int duration; /*!< @brief the time since this sequence started (like, how long the button has been pressed)
-													*   ideally, this would be 0 for activate, (activate.timestamp-get_time()) for status and deactivate */
+	unsigned int duration; /*!< @brief the time since this sequence started (like, how long the
+													*   button has been pressed); not all generators will set this;
+													*   Typically, this would be 0 for activate,
+													*   (activate.timestamp-::get_time()) for status and deactivate */
 };
 
 /*! @file
@@ -149,10 +155,10 @@ class EventBase : public LoadSave {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2004/01/19 07:56:06 $
+ * $Date: 2004/02/09 22:45:28 $
  */
 
 #endif
