@@ -32,6 +32,9 @@ public:
 		: BehaviorBase(), myGenID(mgid), mySourceID(msid), autoListen(true), srcGenID(srcgid), srcSourceID(srcsid), myName(name)
 	{}
 	//@}
+
+	//! destructor - does nothing
+	virtual ~EventGeneratorBase() {}
 	
 	virtual void DoStart();
 	
@@ -81,10 +84,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:57 $
+ * $Date: 2004/02/18 21:12:18 $
  */
 
 #endif
