@@ -26,23 +26,6 @@
 
 using namespace std;
 
-//Compatibility between Aperios versions for different models...
-#if ( TGT_ERS210 || TGT_ERS220 || TGT_ERS2xx )
-const OJointValue4 ojoint4_STATE0      = 0;
-const OJointValue4 ojoint4_STATE1      = 1;
-const ODataType odataLED_COMMAND3         =  263; // LED3 Command
-typedef word OLED3Mode;
-const OLED3Mode oled3_MODE_UNDEF = 0xffff;
-const OLED3Mode oled3_MODE_A     = 0;
-const OLED3Mode oled3_MODE_B     = 1;
-struct OLEDCommandValue3 {
-    sword      intensity;   // 0 - 255
-    OLED3Mode  mode;
-    word       period;      // 1 period : 1 frame (8ms)
-    word       reserved;    // Reserved for OVirtualRobot
-};
-#endif
-
 MMCombo::MMCombo()
 	: OObject(), motmanMemRgn(NULL), worldStateMemRgn(NULL),
 		soundManagerMemRgn(NULL), eventTranslatorQueueMemRgn(NULL),
@@ -652,11 +635,9 @@ MMCombo::SetupOutputs(const bool to_open[NumOutputs])
 				if(open[j]) {
 					OCommandInfo* info = cmdVecData->GetInfo(used);
 					info->Set(odataJOINT_COMMAND4, primIDs[j], NumSlowFrames);
-#if !( TGT_ERS210 || TGT_ERS220 || TGT_ERS2xx )
 					OJointCommandValue4* jval = reinterpret_cast<OJointCommandValue4*>(cmdVecData->GetData(used)->value);
 					for(unsigned int frame=0; frame<NumFrames; frame++)
 						jval[frame].period = 1;
-#endif
 					used++;
 				}
 		} else {
@@ -730,10 +711,10 @@ MMCombo::RPOPENR_send(char *buf, int bufsize) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.49 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.50 $
  * $State: Exp $
- * $Date: 2004/02/02 20:55:50 $
+ * $Date: 2004/03/03 03:37:03 $
  */
 
 
