@@ -34,6 +34,7 @@ EmergencyStopMC::EmergencyStopMC()
 		ledengine.cycle(1<<(NumLEDs-1),period,1,0,period/2);
 		ledengine.cycle(1<<(NumLEDs-2),period,1);
 	}
+	takeSnapshot();
 }
 
 
@@ -52,22 +53,22 @@ int EmergencyStopMC::updateOutputs() {
 		if((get_time()-timeoflastbtn)<duration)
 			setStopped(!paused);
 	}
-	if(paused) {
-		for(unsigned int i=0; i<NumPIDJoints; i++) {
-			piddutyavgs[i]=static_cast<unsigned char>(piddutyavgs[i]*.8+fabs(state->pidduties[i])*255*.2);
-			//reset if there's a force...
-			if(piddutyavgs[i]>pidcutoff) {
-				cmds[i].value-=state->pidduties[i]/10;
-				//				cmds[i].value=state->outputs[i];
-				//				cout << outputNames[i] << ' ' << state->pidduties[i] << ' ' << state->outputs[i] << endl;
-			}
-			//reset if there's just something out of place (perhaps we're being overridden)
-			if(fabs(state->outputs[i]-cmds[i].value)>.1)
-				cmds[i].value=state->outputs[i];
+	if(!paused)
+		return 0;
+	for(unsigned int i=0; i<NumPIDJoints; i++) {
+		piddutyavgs[i]=static_cast<unsigned char>(piddutyavgs[i]*.8+fabs(state->pidduties[i])*255*.2);
+		//reset if there's a force...
+		if(piddutyavgs[i]>pidcutoff) {
+			cmds[i].value-=state->pidduties[i]/10;
+			//				cmds[i].value=state->outputs[i];
+			//				cout << outputNames[i] << ' ' << state->pidduties[i] << ' ' << state->outputs[i] << endl;
 		}
+		//reset if there's just something out of place (perhaps we're being overridden)
+		if(fabs(state->outputs[i]-cmds[i].value)>.1)
+			cmds[i].value=state->outputs[i];
 	}
 	ledengine.updateLEDs(&cmds[LEDOffset]);
-	if(paused && state->robotDesign&WorldState::ERS7Mask) {
+	if(state->robotDesign&WorldState::ERS7Mask) {
 		//a special Battlestar Galactica inspired effect for the ERS-7
 		static float acts[5];
 		static bool first=true;
@@ -202,9 +203,9 @@ bool EmergencyStopMC::trigger() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.19 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2004/01/16 23:55:19 $
+ * $Date: 2004/02/06 23:13:46 $
  */
 
