@@ -310,6 +310,11 @@ void GetLegPosition(vector3d& p, const double* ang, int leg)
 	if(leg % 2)
 		p.y = -p.y;
 }
+void GetLegPosition(vector3d& p, const double* ang, BodyPosition &bp,int leg)
+{
+	GetLegPosition(p,ang,leg);
+	p=p.rotate_y(bp.angle.y).rotate_z(-bp.angle.z)+bp.loc;
+}
 
 
 void GetBodyLocation(vector3d &ball,vector3d &toe,const double *ang,int leg)
@@ -448,9 +453,9 @@ void GetHeadPosition(vector3d &location, vector3d &direction, vector3d &up, vect
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.4 $
- * $State: Rel $
- * $Date: 2003/09/25 15:27:22 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.5 $
+ * $State: Exp $
+ * $Date: 2004/02/26 01:02:49 $
  */
 
