@@ -84,6 +84,7 @@ void GetLegAngles(double *angles,vector3d target[4],BodyPosition &bp);
 
 void GetLegAngles(double *angles,vector3d target,BodyPosition &bp,int leg);
 void GetLegPosition(vector3d& p,const double* ang,int leg);
+void GetLegPosition(vector3d& p, const double* ang, BodyPosition &bp,int leg);
 
 void GetBodyLocation(vector3d &ball,vector3d &toe,const double *ang,int leg);
 
@@ -109,10 +110,10 @@ void GetHeadPosition(vector3d &location, vector3d &direction, vector3d &up, vect
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.7 $
- * $State: Rel $
- * $Date: 2003/09/25 15:27:22 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.8 $
+ * $State: Exp $
+ * $Date: 2004/02/26 01:02:49 $
  */
 
 #endif
