@@ -52,25 +52,26 @@ class MMAccessor {
 	//! constructor, checks out by default
 	/*! @param id the motion command to check out
 	 *  @param ckout if true (default) will checkout upon creation.  otherwise it just gets current address (so you can peek at member fields, which should be safe) */
-	MMAccessor(MotionManager::MC_ID id,bool ckout=true) : mc_id(id), mcptr(NULL) {
+	MMAccessor(MotionManager::MC_ID id,bool ckout=true) : mc_id(id), checkOutCnt(0), mcptr(NULL) {
 		if(ckout)
 			checkout();
 		else
-			mcptr=(MC_t*)motman->peekMotion(id);
+			mcptr=static_cast<MC_t*>(motman->peekMotion(id));
 	}
 
 	//! constructor, allows objects to provide uniform access to MotionCommands, regardless of whether they are currently in the MotionManager
-	MMAccessor(MotionCommand * ptr) : mc_id(invalid_MC_ID), mcptr(ptr) {}
+	MMAccessor(MotionCommand * ptr) : mc_id(invalid_MC_ID), checkOutCnt(0), mcptr(ptr) {}
 
-	//! copy constructor - will reference the same mc_id - checkin/checkouts are independent between this and @a a - motman does counting of checkin/checkouts
-	MMAccessor(const MMAccessor& a) : mc_id(a.mc_id), mcptr(a.mcptr) {
-		if(motman->isOwner(mc_id))
+	//! copy constructor - will reference the same mc_id - checkin/checkouts are independent between this and @a a; however, if @a a is checkout out, @c this will check itself out as well
+	MMAccessor(const MMAccessor& a) : mc_id(a.mc_id), checkOutCnt(0), mcptr(a.mcptr) {
+		if(a.checkOutCnt>0)
 			checkout();
 	}
 
 	//! destructor, checks in if needed
 	~MMAccessor() {
-		checkin();
+		while(checkOutCnt>0)
+			checkin();
 	}
 
 	//! allows assignment of MMAccessor's, similar to the copy constructor - the two MMAccessor's will control the same MotionCommand
@@ -85,7 +86,8 @@ class MMAccessor {
 	//! So you can check out if not done by default (or you checked in already)
 	inline MC_t* checkout() {
 		if(mc_id!=MotionManager::invalid_MC_ID)
-			mcptr=dynamic_cast<MC_t*>(motman->checkoutMotion(mc_id)); 
+			mcptr=static_cast<MC_t*>(motman->checkoutMotion(mc_id));
+		checkOutCnt++;
 		return mcptr;
 	}
 
@@ -95,10 +97,12 @@ class MMAccessor {
 	//! Checks in the motion
 	/*! Don't forget, you can also just limit the scope using extra { }'s */
 	inline void checkin() {
-		if(motman->isOwner(mc_id)) {
+		if(checkOutCnt>0) {
 			motman->checkinMotion(mc_id);
-			mcptr=NULL; // fail fast if we use it after checkin
+			checkOutCnt--;
 		}
+		if(checkOutCnt==0)
+			mcptr=NULL; // fail fast if we use it after last checkin
 	}
 
 	//! Checks in the motion, passing through the value it is passed.
@@ -140,6 +144,7 @@ class MMAccessor {
 
  protected:
 	MotionManager::MC_ID mc_id; //!< the MC_ID that this Accessor was constructed with
+	unsigned int checkOutCnt;   //!< counter so we know how many times checkout was called
 	MC_t* mcptr;                //!< a pointer to the motion command, should always be valid even when not checked out so you can access member fields (which is reasonably safe)
 };
 
@@ -148,10 +153,10 @@ class MMAccessor {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.8 $
- * $State: Rel $
- * $Date: 2003/09/12 21:38:46 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.9 $
+ * $State: Exp $
+ * $Date: 2004/02/18 21:13:02 $
  */
 
 #endif
