@@ -62,13 +62,15 @@ MotionManager::InitAccess(OSubject* subj) {
 
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd& cmd) {
-    if (output >= NumOutputs) return; 
+	if(output >= NumOutputs)
+		return;
+	if(cmd.weight<=0)
+		return;
 
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
 	if(cur_cmd==invalid_MC_ID) {
-		if(cmd.weight>0)
-			cmdSums[output]=cmd.value;
+		cmdSums[output]=cmd.value;
 	} else if(getPriority(cur_cmd)>=kBackgroundPriority) {
 		cmdstatelist_t& curstatelist=cmdstates[output];
 		cmdstatelist_t::index_t ent=curstatelist.begin();
@@ -84,13 +86,15 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd& cmd, unsigned int frame) {
-    if (output >= NumOutputs) return; 
+	if(output >= NumOutputs)
+		return;
+	if(cmd.weight<=0)
+		return;
 
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
 	if(cur_cmd==invalid_MC_ID) {
-		if(cmd.weight>0)
-			cmdSums[output]=cmd.value;
+		cmdSums[output]=cmd.value;
 	} else if(getPriority(cur_cmd)>=kBackgroundPriority) {
 		cmdstatelist_t& curstatelist=cmdstates[output];
 		cmdstatelist_t::index_t ent=curstatelist.begin();
@@ -105,13 +109,22 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void 
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd ocmds[NumFrames]) {
-    if (output >= NumOutputs) return; 
+	if(output >= NumOutputs)
+		return;
+	unsigned int hasWeight=NumFrames;
+	for(unsigned int i=NumFrames-1; i!=0; i--)
+		if(ocmds[i].weight>0) {
+			hasWeight=i;
+			break;
+		}
+	if(hasWeight==NumFrames)
+		return;
+	
 
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
 	if(cur_cmd==invalid_MC_ID) {
-		if(ocmds[NumFrames-1].weight>0)
-			cmdSums[output]=ocmds[NumFrames-1].value;
+		cmdSums[output]=ocmds[hasWeight].value;
 	} else if(getPriority(cur_cmd)>=kBackgroundPriority) {
 		cmdstatelist_t& curstatelist=cmdstates[output];
 		cmdstatelist_t::index_t ent=curstatelist.begin();
@@ -127,7 +140,8 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputPID& pid) {
-    if (output >= NumOutputs) return; 
+	if(output >= NumOutputs)
+		return;
 
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
@@ -147,7 +161,8 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd& cmd, const OutputPID& pid) {
-    if (output >= NumOutputs) return; 
+	if(output >= NumOutputs)
+		return;
 
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
@@ -172,7 +187,8 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd ocmds[NumFrames], const OutputPID& pid) {
-    if (output >= NumOutputs) return; 
+	if(output >= NumOutputs)
+		return;
 
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
@@ -744,10 +760,10 @@ MotionManager::OutputState::OutputState(unsigned int /*out*/, float pri, MC_ID m
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.33 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.34 $
  * $State: Exp $
- * $Date: 2004/01/14 20:45:01 $
+ * $Date: 2004/02/07 01:02:29 $
  */
 
 
