@@ -109,9 +109,8 @@ void WalkMC::init(const char* pfile)
   body_loc.init(vector3d(0,0,wp.body_height),vector3d(0,0,0));
   body_angle.init(vector3d(0,wp.body_angle,0),vector3d(0,0,0));
 
-  for(unsigned int i=0; i<4; i++){
+  for(unsigned int i=0; i<NumLegs; i++)
     legw[i].air = false;
-  }
 
 	if(pfile!=NULL)
 		LoadFile(pfile);
@@ -121,8 +120,7 @@ void WalkMC::init(const char* pfile)
 	double zeros[JointsPerLeg];
 	for(unsigned int i=0; i<JointsPerLeg; i++)
 		zeros[i]=0;
-	for(unsigned int i=0; i<NumLegs; i++)
-		GetLegPosition(legpos[i],zeros,i);
+	resetLegPos();
 
 	//	cmds[HeadOffset+TiltOffset].set(.3333,1);
 }
@@ -130,11 +128,11 @@ void WalkMC::init(const char* pfile)
 // tss "SmoothWalk" addition follows
 int WalkMC::isDirty()
 {
-  if(isPaused) return false;
+  if(isPaused)
+		return false;
   if((target_vel_xya.x == 0) && (target_vel_xya.y == 0) && (target_vel_xya.z == 0)) {
-	if((vel_xya.x != 0) || (vel_xya.y != 0) || (vel_xya.z != 0)) return true
-;
-	else return false;
+		// we may stopping, but not stopped yet...
+		return ((vel_xya.x != 0) || (vel_xya.y != 0) || (vel_xya.z != 0));
   }
   return true;
 }
@@ -223,6 +221,11 @@ int WalkMC::updateOutputs() {
 	if(!isDirty())
 		return 0;
 
+	if(vel_xya.sqlength()==0) {
+		// we had been stopped - better check someone else didn't move the legs while we weren't using them...
+		resetLegPos(); 
+	}
+
 	unsigned int curT=get_time();
 	if(last_target_vel_xya!=target_vel_xya) {
 		last_target_vel_xya=target_vel_xya;
@@ -235,7 +238,10 @@ int WalkMC::updateOutputs() {
   double t = TimeStep * slowmo / 1000;
 
 	vector3d cal_target_vel_xya(target_vel_xya);
-	cal_target_vel_xya.x/=cp.max_vel[CalibrationParam::forward];
+	if(target_vel_xya.x<0)
+		cal_target_vel_xya.x/=cp.max_vel[CalibrationParam::reverse];
+	else
+		cal_target_vel_xya.x/=cp.max_vel[CalibrationParam::forward];
 	cal_target_vel_xya.y/=cp.max_vel[CalibrationParam::strafe];
 	cal_target_vel_xya.z/=cp.max_vel[CalibrationParam::rotate];
 	if(cal_target_vel_xya.sqlength()>.0025)
@@ -244,9 +250,13 @@ int WalkMC::updateOutputs() {
 		else
 			applyCalibration(cp.f_calibration,target_vel_xya,cal_target_vel_xya);
 
-  vel_xya.x = bound(cal_target_vel_xya.x, vel_xya.x-max_accel_xya.x*t, vel_xya.x+max_accel_xya.x*t);
+  //software accel:
+	vel_xya.x = bound(cal_target_vel_xya.x, vel_xya.x-max_accel_xya.x*t, vel_xya.x+max_accel_xya.x*t);
   vel_xya.y = bound(cal_target_vel_xya.y, vel_xya.y-max_accel_xya.y*t, vel_xya.y+max_accel_xya.y*t);
   vel_xya.z = bound(cal_target_vel_xya.z, vel_xya.z-max_accel_xya.z*t, vel_xya.z+max_accel_xya.z*t);
+	//no software accel:
+	//vel_xya=cal_target_vel_xya;
+	//<end>
 
   BodyPosition delta;
   delta.loc.set(vel_xya.x*t,vel_xya.y*t,0);
@@ -299,12 +309,26 @@ int WalkMC::updateOutputs() {
 
 			if(air != legw[i].air){
 				if(air){
+					/*
+						cout << i << ":   ";
+						cout << legpos[i].x << ' ' << legpos[i].y << ' ' << legpos[i].z << "  ->  ";
+						GetLegAngles(nextlegangles,legpos[i],nextpos,i);
+						for(unsigned int j=0; j<JointsPerLeg; j++)
+							cout << nextlegangles[j] << ' ';
+						cout << endl;
+					*/
 					t = wp.period/1000.0 * 0.75;
 					vector3d vfp;
+					//software accel:
 					vfp.x = bound(cal_target_vel_xya.x, vel_xya.x-max_accel_xya.x*t, vel_xya.x+max_accel_xya.x*t);
 					vfp.y = bound(cal_target_vel_xya.y, vel_xya.y-max_accel_xya.y*t, vel_xya.y+max_accel_xya.y*t);
-					vfp.z = 0.0;
 					double vfa   = bound(cal_target_vel_xya.z, vel_xya.z-max_accel_xya.z*t, vel_xya.z+max_accel_xya.z*t);
+					//no software accel:
+					//vfp.x=cal_target_vel_xya.x;
+					//vfp.y=cal_target_vel_xya.y;
+					//double vfa=cal_target_vel_xya.z;
+					//<end>
+					vfp.z = 0.0;
 					double b = (wp.period/1000.0) * (1.0 - air_f) / 2.0;
 					vector3d target = (wp.leg[i].neutral + vfp*b).rotate_z(vfa*b);
 					legw[i].airpath.create(legpos[i],target,wp.leg[i].lift_vel,wp.leg[i].down_vel);
@@ -327,7 +351,7 @@ int WalkMC::updateOutputs() {
 				// with velocity.
 				double velfraction_x = fabs(vel_xya.x / MAX_DX);
 				double velfraction_y = fabs(vel_xya.y / MAX_DY);
-				double velfraction_a = fabs(vel_xya.z / MAX_DA);
+				double velfraction_a = fabs(vel_xya.z / MAX_DA * 2); //rotation seems more sensitive
 
 				// Choose the biggest velfraction
 				double velfraction =
@@ -367,12 +391,21 @@ int WalkMC::updateOutputs() {
 }
 
 void WalkMC::resetLegPos() {
+	BodyPosition nextpos;
+	nextpos.loc.set(0,0,wp.body_height);
+	nextpos.angle.set(0,wp.body_angle,0);
 	for(unsigned int i=0; i<NumLegs; i++) {
 		double tmp[JointsPerLeg];
 		for(unsigned int j=0; j<JointsPerLeg; j++)
 			tmp[j]=state->outputs[LegOffset+i*JointsPerLeg+j];
-		GetLegPosition(legpos[i],tmp,i);
+		GetLegPosition(legpos[i],tmp,nextpos,i);
+		/*
+			for(unsigned int j=0; j<JointsPerLeg; j++)
+			cout << state->outputs[LegOffset+i*JointsPerLeg+j] << ' ';
+			cout << "  ->  " << legpos[i].x << ' ' << legpos[i].y << ' ' << legpos[i].z << endl;
+		*/
 	}
+	//cout << "----------------------" << endl;
 }
 
 unsigned int checksum(const char *data,int num)
@@ -396,7 +429,7 @@ void WalkMC::applyCalibration(const float mat[3][11], const vector3d& in, vector
 	inmat[2]=in.z;
 	inmat[3]=fabs(in.y);
 	inmat[4]=fabs(in.z);
-	inmat[5]=atan2(in.y,inmat[3]);
+	inmat[5]=exp(-.5f*in.z*in.z)*sin(in.z*2.5f);
 	inmat[6]=in.x*in.x+in.y*in.y;
 	inmat[7]=in.x*in.z;
 	inmat[8]=in.y*in.x;
@@ -419,9 +452,9 @@ void WalkMC::applyCalibration(const float mat[3][11], const vector3d& in, vector
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.23 $
  * $State: Exp $
- * $Date: 2004/01/19 20:36:06 $
+ * $Date: 2004/02/26 01:02:49 $
  */
 
