@@ -44,6 +44,27 @@
 /*! Moves the feet through a looping path in order to walk - default parameters use
  *  a walk low to the ground so you don't walk over the ball.
  *
+ *  There are around 50 parameters which control the walk - these are
+ *  loaded from a file and can modify almost every aspect of the the
+ *  gait.  It's a binary file format, I recommend using our Walk Edit
+ *  menu to edit the parameters in real time and get immediate
+ *  feedback.  It's a tricky job to find a good set of parameters.
+ *
+ *  And then, once you have it walking, there's a whole different
+ *  problem of actually moving at the speed that's requested.  That's
+ *  what the calibration parameters do - map the requested target
+ *  speed to the command to pass to the engine so the resulting motion
+ *  will hopefully match what you asked for.
+ *
+ *  You'll probably want to take a look at the setTargetVelocity()
+ *  function to control the direction of the walk.
+ *
+ *  This class is in some dire need of some cleanup - we (Tekkotsu)
+ *  didn't write it, never really bothered to get a deep understanding
+ *  of it, but have none the less hacked around and added stuff on top
+ *  of it.  So pardon the mess, unless you're feeling ambitious to
+ *  write your own ;)
+ *
  *  This portion of the code falls under CMPack's license:
  *  @verbinclude CMPack_license.txt
  *
@@ -96,8 +117,8 @@ public:
 			NUM_DIM
 		};
 
-		float f_calibration[3][11]; //!< matrix of calibration parameters; 3 columns for f,s,r speeds, 2 columns for abs s,r speeds, 1 squared planar speed, 1 planar bearing, 3 columns for f*r,s*f,r*s, and 1 column for offset
-		float b_calibration[3][11]; //!< matrix of calibration parameters; 3 columns for f,s,r speeds, 2 columns for abs s,r speeds, 1 squared planar speed, 1 planar bearing, 3 columns for f*r,s*f,r*s, and 1 column for offset
+		float f_calibration[3][11]; //!< matrix of calibration parameters; 3 columns for f,s,r speeds, 2 columns for abs s,r speeds, 1 gabor function, 1 squared planar speed, 3 columns for f*r,s*f,r*s, and 1 column for offset
+		float b_calibration[3][11]; //!< matrix of calibration parameters; 3 columns for f,s,r speeds, 2 columns for abs s,r speeds, 1 gabor function, 1 squared planar speed, 3 columns for f*r,s*f,r*s, and 1 column for offset
 
 		float max_accel[NUM_DIM]; //!< maximum achievable acceleration, 0 for infinite (mm/s^2)
 		float max_vel[NUM_DIM]; //!< maximum achievable velocity (mm/s)
@@ -168,7 +189,7 @@ public:
 	static void applyCalibration(const float mat[3][11], const vector3d& in, vector3d& out);
 
  protected:
-	//! does some setup stuff, calls load(pfile)
+	//! does some setup stuff, calls LoadFile(pfile)
 	void init(const char* pfile);
 
 	bool isPaused; //!< true if we are paused
@@ -241,10 +262,10 @@ public:
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.19 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:57 $
+ * $Date: 2004/03/03 18:42:16 $
  */
 
 #endif
