@@ -33,7 +33,7 @@ namespace ERS210Info {
 	const unsigned int NumSlowFrames=1;    //!< the number of frames per buffer being sent to ears (double buffered as well)
 	const unsigned int SoundBufferTime=32; //!< the number of milliseconds per sound buffer... I'm not sure if this can be changed
 	
-	//!Corresponds to entries in PrimitiveName, defined at the end of this file, these are the primary grouping
+	//!Corresponds to entries in ERS210Info::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
 	const unsigned NumPIDJoints   = 18; //!< The number of joints which use PID motion - everything except ears
@@ -42,7 +42,7 @@ namespace ERS210Info {
 	const unsigned NumOutputs     = NumPIDJoints + NumBinJoints + NumLEDs; //!< the total number of outputs
 
 	const bool IsFastOutput[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,false,false }; //!< true for joints which can be updated every 32 ms (all but the ears)
-	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in compatability mode
+	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in ERS-2xx target mode
 	const bool IsRealERS210[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true };
 	//@}
 
@@ -53,8 +53,8 @@ namespace ERS210Info {
 	const unsigned NumTailJoints  =  2; //!< The number of joints assigned to the tail
 	const unsigned NumMouthJoints =  1; //!< the number of joints that control the mouth
 	const unsigned NumEarJoints   =  2; //!< The number of joints which control the ears (NOT per ear, is total)
-	const unsigned NumButtons     =  8; //!< the number of buttons that are available, see ButtonOffset_t
-	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see SensorOffset_t
+	const unsigned NumButtons     =  8; //!< the number of buttons that are available, see ERS210Info::ButtonOffset_t
+	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see ERS210Info::SensorOffset_t
 	
 
 	// *******************************
@@ -62,7 +62,7 @@ namespace ERS210Info {
 	// *******************************
 
 
-	//!Corresponds to entries in PrimitiveName, defined at the end of this file
+	//!Corresponds to entries in ERS210Info::PrimitiveName, defined at the end of this file
 	//!@name Output Offsets
 
 	const unsigned PIDJointOffset = 0; //!< The beginning of the PID Joints
@@ -86,7 +86,7 @@ namespace ERS210Info {
 	
 	//@}
 	
-	//! The offsets of the individual LEDs on the head and tail.  Note that L/R are robot's POV.  See also LEDBitMask_t
+	//! The offsets of the individual LEDs on the head and tail.  Note that left/right are robot's point of view.  See also LEDBitMask_t
 	enum LEDOffset_t {
 		BotLLEDOffset = LEDOffset,//!< bottom left (red - sad)
 		BotRLEDOffset, //!< bottom right (red - sad)
@@ -110,7 +110,7 @@ namespace ERS210Info {
 		TailLeftLEDOffset = TlBluLEDOffset        //!< alias for 220 cross-compatibility
 	};
 	
-	//! Bitmasks for use when specifying combinations of LEDs (see LEDEngine ) Note that L/R are robot's POV
+	//! Bitmasks for use when specifying combinations of LEDs (see LedEngine ) Note that left/right are robot's point of view
 	//!@name LED Bitmasks
 	typedef unsigned int LEDBitMask_t; //!< So you can be clear when you're refering to a LED bitmask
 	const LEDBitMask_t BotLLEDMask = 1<<(BotLLEDOffset-LEDOffset); //!< bottom left (red - sad)
@@ -368,7 +368,7 @@ namespace ERS210Info {
 	#define __RI_RAD_FLAG
 	#endif
 	
-	//! Defines the min and max index of entries in #outputRanges and #mechanicalLimits
+	//! Defines the indexes to use to access the min and max entries of ERS210Info::outputRanges and ERS210Info::mechanicalLimits
 	enum MinMaxRange_t { MinRange,MaxRange };
 
 	//! This table holds the software limits of each of the outputs
@@ -417,8 +417,8 @@ namespace ERS210Info {
 #endif //TGT_ERS2xx check
 
 	/*! @name CPC IDs
-	 * values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ::PrimitiveName */
-	static const int CPCJointNeckTilt           =  0; //!< Head
+	 * values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ERS210Info::PrimitiveName */
+	static const int CPCJointNeckTilt           =  0; // Head
 	static const int CPCJointNeckPan            =  1;
 	static const int CPCJointNeckRoll           =  2;
 	static const int CPCSensorHeadBackPressure  =  3;
@@ -426,23 +426,23 @@ namespace ERS210Info {
 	static const int CPCSensorPSD               =  5;
 	static const int CPCJointMouth              =  6;
 	static const int CPCSensorChinSwitch        =  7;
-	static const int CPCJointLFRotator          =  8; //!< Left front leg
+	static const int CPCJointLFRotator          =  8; // Left front leg
 	static const int CPCJointLFElevator         =  9;
 	static const int CPCJointLFKnee             = 10;
 	static const int CPCSensorLFPaw             = 11;
-	static const int CPCJointLHRotator          = 12; //!< Left hind leg
+	static const int CPCJointLHRotator          = 12; // Left hind leg
 	static const int CPCJointLHElevator         = 13;
 	static const int CPCJointLHKnee             = 14;
 	static const int CPCSensorLHPaw             = 15;
-	static const int CPCJointRFRotator          = 16; //!< Right front leg
+	static const int CPCJointRFRotator          = 16; // Right front leg
 	static const int CPCJointRFElevator         = 17;
 	static const int CPCJointRFKnee             = 18;
 	static const int CPCSensorRFPaw             = 19;
-	static const int CPCJointRHRotator          = 20; //!< Right hind leg
+	static const int CPCJointRHRotator          = 20; // Right hind leg
 	static const int CPCJointRHElevator         = 21;
 	static const int CPCJointRHKnee             = 22;
 	static const int CPCSensorRHPaw             = 23;
-	static const int CPCJointTailPan            = 24; //!< Tail
+	static const int CPCJointTailPan            = 24; // Tail
 	static const int CPCJointTailTilt           = 25;
 	static const int CPCSensorThermoSensor      = 26;
 	static const int CPCSensorBackSwitch        = 27;
@@ -458,10 +458,10 @@ namespace ERS210Info {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2004/01/21 03:53:01 $
+ * $Date: 2004/02/09 22:45:28 $
  */
 
 #endif
