@@ -36,7 +36,7 @@ namespace ERS220Info {
 	const unsigned int NumSlowFrames=1;    //!< the number of frames per buffer being sent to ears (double buffered as well)
 	const unsigned int SoundBufferTime=32; //!< the number of milliseconds per sound buffer... I'm not sure if this can be changed
 	
-	//!Corresponds to entries in PrimitiveName, defined at the end of this file, these are the primary grouping
+	//!Corresponds to entries in ERS220Info::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
 	const unsigned NumPIDJoints   = 15; //!< The number of joints which use PID motion - everything
@@ -63,7 +63,7 @@ namespace ERS220Info {
 		// for binary joints (none supported/exist on 220)
 	}; //!< true for joints which can be updated every 32 ms (all but the ears on a 210)
 
-	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in compatability mode
+	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in ERS-2xx target mode
 	const bool IsRealERS220[NumOutputs] = {
 		// for PID joints
 		true, true, true,
@@ -90,8 +90,8 @@ namespace ERS220Info {
 	const unsigned NumTailJoints  =  0; //!< The number of joints assigned to the tail
 	const unsigned NumMouthJoints =  0; //!< the number of joints that control the mouth
 	const unsigned NumEarJoints   =  0; //!< The number of joints which control the ears (NOT per ear, is total)
-	const unsigned NumButtons     =  11; //!< the number of buttons that are available, see ButtonOffset_t
-	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see SensorOffset_t
+	const unsigned NumButtons     =  11; //!< the number of buttons that are available, see ERS220Info::ButtonOffset_t
+	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see ERS220Info::SensorOffset_t
 	
 
 	// *******************************
@@ -99,7 +99,7 @@ namespace ERS220Info {
 	// *******************************
 
 
-	//!Corresponds to entries in PrimitiveName, defined at the end of this file
+	//!Corresponds to entries in ERS220Info::PrimitiveName, defined at the end of this file
 	//!@name Output Offsets
 	const unsigned PIDJointOffset = 0; //!< The beginning of the PID Joints
 	const unsigned LegOffset   = PIDJointOffset;           //!< the offset of the beginning of the leg joints
@@ -119,7 +119,7 @@ namespace ERS220Info {
 	
 	//@}
 	
-	//! The offsets of the individual LEDs on the head and tail.  Note that L/R are robot's POV.  See also LEDBitMask_t
+	//! The offsets of the individual LEDs on the head and tail.  Note that left/right are robot's point of view.  See also LEDBitMask_t
 	enum LEDOffset_t {
 		FaceFrontLeftLEDOffset = LEDOffset, //!< head face side light (front left - blue)
 		FaceFrontRightLEDOffset,    //!< head face side light (front right - blue)
@@ -154,7 +154,7 @@ namespace ERS220Info {
 		TlRedLEDOffset = TailRightLEDOffset,      //!< red tail light (ERS-210)
 	};
 	
-	//! Bitmasks for use when specifying combinations of LEDs (see LEDEngine ) Note that L/R are robot's POV
+	//! Bitmasks for use when specifying combinations of LEDs (see LedEngine ) Note that left/right are robot's point of view
 	//!@name LED Bitmasks
 	typedef unsigned int LEDBitMask_t; //!< So you can be clear when you're refering to a LED bitmask
 	const LEDBitMask_t FaceFrontLeftLEDMask   = 1<<(FaceFrontLeftLEDOffset-LEDOffset);
@@ -470,7 +470,7 @@ namespace ERS220Info {
 #define __RI_RAD_FLAG
 #endif
 
-	//! Defines the min and max index of entries in #outputRanges and #mechanicalLimits
+	//! Defines the indexes to use to access the min and max entries of ERSInfo::outputRanges and ERS7Info::mechanicalLimits
 	enum MinMaxRange_t { MinRange,MaxRange };
 
 	//! This table holds the software limits of each of the outputs
@@ -521,7 +521,7 @@ namespace ERS220Info {
 #endif //TGT_ERS2xx check
 
 	/*! @name CPC IDs
-	 * values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ::PrimitiveName */
+	 * values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ERS220Info::PrimitiveName */
     static const int CPCJointNeckTilt           =  0; // PRM:/r1/c1-Joint2:j1
     static const int CPCJointNeckPan            =  1; // PRM:/r1/c1/c2-Joint2:j2
     static const int CPCJointNeckRoll           =  2; // PRM:/r1/c1/c2/c3-Joint2:j3
@@ -562,10 +562,10 @@ namespace ERS220Info {
  * @author Daishi MORI (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2004/01/21 03:53:01 $
+ * $Date: 2004/02/09 22:45:28 $
  */
 
 #endif
