@@ -32,7 +32,7 @@ namespace ERS2xxInfo {
 	const unsigned int NumSlowFrames=1;    //!< the number of frames per buffer being sent to ears (double buffered as well)
 	const unsigned int SoundBufferTime=32; //!< the number of milliseconds per sound buffer... I'm not sure if this can be changed
 	
-	//!Corresponds to entries in PrimitiveName, defined at the end of this file, these are the primary grouping
+	//!Corresponds to entries in ERS2xxInfo::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
 	const unsigned NumPIDJoints   = 18; //!< The number of joints which use PID motion - everything
@@ -118,8 +118,8 @@ namespace ERS2xxInfo {
 	const unsigned NumTailJoints  =  2; //!< The number of joints assigned to the tail
 	const unsigned NumMouthJoints =  1; //!< the number of joints that control the mouth
 	const unsigned NumEarJoints   =  2; //!< The number of joints which control the ears (NOT per ear, is total)
-	const unsigned NumButtons     =  11; //!< the number of buttons that are available, see ButtonOffset_t
-	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see SensorOffset_t
+	const unsigned NumButtons     =  11; //!< the number of buttons that are available, see ERS2xxInfo::ButtonOffset_t
+	const unsigned NumSensors     =  1+3+1+5;  //!< 1 dist, 3 accel, 1 thermo, 5 from power, see ERS2xxInfo::SensorOffset_t
 	
 
 	// *******************************
@@ -127,7 +127,7 @@ namespace ERS2xxInfo {
 	// *******************************
 
 
-	//!Corresponds to entries in PrimitiveName, defined at the end of this file
+	//!Corresponds to entries in ERS2xxInfo::PrimitiveName, defined at the end of this file
 	//!@name Output Offsets
 	const unsigned PIDJointOffset = 0; //!< The beginning of the PID Joints
 	const unsigned LegOffset   = PIDJointOffset;           //!< the offset of the beginning of the leg joints
@@ -150,7 +150,7 @@ namespace ERS2xxInfo {
 	
 	//@}
 	
-	//! The offsets of the individual LEDs on the head and tail.  Note that L/R are robot's POV.  See also LEDBitMask_t
+	//! The offsets of the individual LEDs on the head and tail.  Note that left/right are robot's point of view.  See also LEDBitMask_t
 	enum LEDOffset_t {
 		FaceFrontLeftLEDOffset = LEDOffset, //!< head face side light (front left - blue) (ERS-220)
 		FaceFrontRightLEDOffset,    //!< head face side light (front right - blue) (ERS-220)
@@ -186,7 +186,7 @@ namespace ERS2xxInfo {
 		TopBrLEDOffset = ModeLEDOffset,           //!< top bar (green) (ERS-210)
 	};
 	
-	//! Bitmasks for use when specifying combinations of LEDs (see LEDEngine ) Note that L/R are robot's POV
+	//! Bitmasks for use when specifying combinations of LEDs (see LEDEngine ) Note that left/right are robot's point of view
 	//!@name LED Bitmasks
 	typedef unsigned int LEDBitMask_t; //!< So you can be clear when you're refering to a LED bitmask
 	const LEDBitMask_t FaceFrontLeftLEDMask   = 1<<(FaceFrontLeftLEDOffset-LEDOffset);
@@ -535,7 +535,7 @@ namespace ERS2xxInfo {
 #define __RI_RAD_FLAG
 #endif
 
-	//! Defines the min and max index of entries in #outputRanges and #mechanicalLimits
+	//! Defines the indexes to use to access the min and max entries of ERS2xxInfo::outputRanges and ERS2xxInfo::mechanicalLimits
 	enum MinMaxRange_t { MinRange,MaxRange };
 
 	//! This table holds the software limits of each of the outputs
@@ -604,10 +604,10 @@ namespace ERS2xxInfo {
  * @author Daishi MORI (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/01/21 03:53:01 $
+ * $Date: 2004/02/09 22:45:28 $
  */
 
 #endif
