@@ -22,11 +22,11 @@ namespace ERS7Info {
 
 	const unsigned int FrameTime=8;        //!< time between frames in the motion system (milliseconds)
 	const unsigned int NumFrames=4;        //!< the number of frames per buffer (don't forget also double buffered)
-	const unsigned int SlowFrameTime=128;  //!< time between frames for the ears (which move slower for some reason, don't want to mix with other outputs) (milliseconds)
-	const unsigned int NumSlowFrames=1;    //!< the number of frames per buffer being sent to ears (double buffered as well)
+	const unsigned int SlowFrameTime=8;  //!< time between frames for the ears (ERS-7 doesn't seem to have any "slow" joints; this only applied for the ears on the ERS-210)
+	const unsigned int NumSlowFrames=4;    //!< the number of frames per buffer being sent to ears (double buffered as well)
 	const unsigned int SoundBufferTime=32; //!< the number of milliseconds per sound buffer... I'm not sure if this can be changed
 	
-	//!Corresponds to entries in PrimitiveName, defined at the end of this file, these are the primary grouping
+	//!Corresponds to entries in ERS7Info::PrimitiveName, defined at the end of this file, these are the primary grouping
 	/*!Right now all binary joints are slow, but perhaps this won't always be the case... hence the IsFast/Slow bitmasks to select which type, in order to be more general */
 	//!@name Output Types Information
 	const unsigned NumPIDJoints   = 18; //!< The number of joints which use PID motion - everything except ears
@@ -55,8 +55,8 @@ namespace ERS7Info {
 	const unsigned NumTailJoints  =  2; //!< The number of joints assigned to the tail
 	const unsigned NumMouthJoints =  1; //!< the number of joints that control the mouth
 	const unsigned NumEarJoints   =  2; //!< The number of joints which control the ears (NOT per ear, is total)
-	const unsigned NumButtons     =  2+4+3+1; //!< the number of buttons that are available, 2 head, 4 paws, 3 back, 1 underbelly see ButtonOffset_t
-	const unsigned NumSensors     =  3+3+5;  //!< 3 IR (distance), 3 accel (force), 5 from power, see SensorOffset_t
+	const unsigned NumButtons     =  2+4+3+1; //!< the number of buttons that are available, 2 head, 4 paws, 3 back, 1 underbelly see ERS7Info::ButtonOffset_t
+	const unsigned NumSensors     =  3+3+5;  //!< 3 IR (distance), 3 accel (force), 5 from power, see ERS7Info::SensorOffset_t
 	
 
 	// *******************************
@@ -64,7 +64,7 @@ namespace ERS7Info {
 	// *******************************
 
 
-	//!Corresponds to entries in PrimitiveName, defined at the end of this file
+	//!Corresponds to entries in ERS7Info::PrimitiveName, defined at the end of this file
 	//!@name Output Offsets
 
 	const unsigned PIDJointOffset = 0; //!< The beginning of the PID Joints
@@ -88,7 +88,7 @@ namespace ERS7Info {
 	
 	//@}
 	
-	//! The offsets of the individual LEDs on the head and tail.  Note that L/R are robot's POV.  See also LEDBitMask_t
+	//! The offsets of the individual LEDs on the head and tail.  Note that left/right are robot's point of view.  See also LEDBitMask_t
 	enum LEDOffset_t {
 		HeadColorLEDOffset = LEDOffset,
 		HeadWhiteLEDOffset,
@@ -117,7 +117,7 @@ namespace ERS7Info {
 		TlBluLEDOffset= FrBackColorLEDOffset //!< blue tail light
 	};
 	
-	//! Bitmasks for use when specifying combinations of LEDs (see LEDEngine ) Note that L/R are robot's POV
+	//! Bitmasks for use when specifying combinations of LEDs (see LedEngine ) Note that left/right are robot's point of view
 	//!@name LED Bitmasks
 	typedef unsigned int LEDBitMask_t; //!< So you can be clear when you're refering to a LED bitmask
 	
@@ -408,7 +408,7 @@ namespace ERS7Info {
 	#define __RI_RAD_FLAG
 	#endif
 	
-	//! Defines the min and max index of entries in #outputRanges and #mechanicalLimits
+	//! Defines the indexes to use to access the min and max entries of ERS7Info::outputRanges and ERS7Info::mechanicalLimits
 	enum MinMaxRange_t { MinRange,MaxRange };
 
 	//! This table holds the software limits of each of the outputs
@@ -459,7 +459,7 @@ namespace ERS7Info {
 
 
 	/*! @name CPC IDs
-	 * values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ::PrimitiveName */
+	 * values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ERS7Info::PrimitiveName */
 	static const int CPCJointMouth      =  0; //!< Mouth                           
 	static const int CPCSwitchChin      =  1; //!< Chin sensor                     
 	static const int CPCJointNeckNod    =  2; //!< Neck tilt2                      
@@ -503,10 +503,10 @@ namespace ERS7Info {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/01/21 03:53:01 $
+ * $Date: 2004/02/09 22:45:28 $
  */
 
 #endif
