@@ -19,37 +19,45 @@ class EventRouter;
 
 //The following SourceIDs are for events created by WorldState's event generators
 
-//! holds source ID types for sensor events; see EventBase, see SensorSourceID_t
+//! holds source ID types for sensor events; see EventBase, see #SensorSourceID_t
 namespace SensorSourceID {
 	//! holds source ID types for sensor events
+	/*! May want to add a proximity alarm for IR distance?  Probably
+	 *  should do it from a separate generator to avoid screwing up
+	 *  behaviors relying on the current setup
+	 */
 	enum SensorSourceID_t {
-		//may want to add a proximity alarm for IR distance?
-		//probably should do it from a separate generator to avoid
-		//screwing up behaviors relying on the current setup
 		UpdatedSID //!< sends status event as last event after processing a frame
 	};
 }
 
-//! holds source ID types for power events; see EventBase, see PowerSourceID_t
+//! holds source ID types for power events; see EventBase, see #PowerSourceID_t
 namespace PowerSourceID {
 	//! holds source ID types for power events
-	/*! Also serve as offsets into ::powerFlags[]
-	 *  I've never seen a lot of these events thrown by the OS.  NS means never-seen, which
-	 *  could simply be because i haven't put it in that situation (don't have a station-type power
-	 *  charger) or because the OS doesn't actually support sending that flag.
+	/*! Also serve as offsets into WorldState::powerFlags[].
 	 *
-	 *  Under normal conditions, you'll see MotorPowerSID, BatteryConnectSID, DischargingSID, and
-	 *  PowerGoodSID always active with occasional VibrationSID and UpdateSID. When the chest
-	 *  button is pushed, PauseSID is activated and MotorPowerSID is deactivated.
+	 *  I've never seen a lot of these events thrown by the OS.  'NS'
+	 *  means never-seen, which could simply be because i haven't put it
+	 *  in that situation (don't have a station-type power charger) or
+	 *  because the OS doesn't actually support sending that flag.
 	 *
-	 *  The BatteryMonitorBehavior will give a warning once power begins getting low.  The OS won't
-	 *  boot off a battery with less than 15% power remaining (which is when the LowPowerWarnSID is
-	 *  thrown)
+	 *  Under normal conditions, you'll see MotorPowerSID,
+	 *  BatteryConnectSID, DischargingSID, and PowerGoodSID always
+	 *  active with occasional VibrationSID and UpdateSID.  When the
+	 *  chest button is pushed, PauseSID is activated and MotorPowerSID
+	 *  is deactivated.
 	 *
-	 *  @note there's not a one-to-one correspondance of the events from the
-	 *  OPENR power system... i map several OPENR events to fewer Tekkotsu events, check the name
-	 *  if you want to know the specific source (say if low battery is low current and/or low voltage)
-	 *  Status ETIDS are only generated when one of a related group goes on/off but others are still active*/
+	 *  The BatteryMonitorBehavior will give a warning once power begins
+	 *  getting low.  The OS won't boot off a battery with less than 15%
+	 *  power remaining (which is when the LowPowerWarnSID is thrown)
+	 *
+	 *  @note there's not a one-to-one correspondance of the events from
+	 *  the OPENR power system... i map several OPENR events to fewer
+	 *  Tekkotsu events, check the event's name if you want to know the
+	 *  specific source (say if low battery is low current and/or low
+	 *  voltage) Status ETIDS are only generated when one of a related
+	 *  group goes on/off but others are still active
+	 */
 	enum PowerSourceID_t {
 		PauseSID=0, //!< the chest button was pushed (this is not a normal button, it kills power to the motors in hardware)
 		MotorPowerSID, //!< active while the motors have power
@@ -79,23 +87,29 @@ namespace PowerSourceID {
 		SpecialModeSID, //!< ? NS
 		BMNDebugModeSID, //!< ? NS
 		PlungerSID, //!< I think this is in reference to having a memorystick (?) NS
-		UpdatedSID, //!<sent as last event after processing a frame
+		UpdatedSID, //!< sent as last event after processing a frame
 		NumPowerSIDs
 	};
 }
 	
 //! The state of the robot and its environment
-/* Contains sensor readings, current joint positions, etc.\n
- * This is a shared memory region between MainObj, MotoObj, and possibly others in the future\n
- * Be very careful about including structures that use pointers in this class... they will only be valid
- * from the OObject that created them, others may cause a crash if they try to access them.
+/*! Contains sensor readings, current joint positions, etc.\n
+ * This is a shared memory region between MainObj, MotoObj, and possibly others in the future
  *
- * WorldState takes power and sensor updates from the system and maintains the last known
- * values in its member fields.  It throws events when some of these values change, listed in
- * the ButtonSourceID, SensorSourceID, and PowerSourceID namespaces.
+ * Be very careful about including structures that use pointers in
+ * this class... they will only be valid from the OObject that created
+ * them, others may cause a crash if they try to access them.
  *
- * Status events for buttons are always generated unless the WorldState::alwaysGenerateStatus flag
- * is turned off, in which case they are only generated when a value has changed (the top head buttons)
+ * WorldState takes power and sensor updates from the system and
+ * maintains the last known values in its member fields.  It throws
+ * events when some of these values change, listed in the
+ * ButtonSourceID, SensorSourceID, and PowerSourceID namespaces.
+ *
+ * Status events for buttons only generated if the
+ * WorldState::alwaysGenerateStatus flag is turned on, otherwise, by
+ * default, they are only generated when a value has changed
+ * (i.e. when the pressure sensitive buttons get a new pressure
+ * reading)
  */
 class WorldState {
 public:
@@ -104,20 +118,20 @@ public:
 
 	bool alwaysGenerateStatus; //!< controls whether status events are generated for the boolean buttons
 
-	float outputs[NumOutputs];     //!< last sensed positions of joints, for ears, x<.5 is up, x>=.5 is down
-	float buttons[NumButtons];     //!< magnitude is pressure for some, 0/1 for others
-	float sensors[NumSensors];     //!< IR, Accel, Thermo, Power stuff
-	float pids[NumPIDJoints][3];   //!< current PID settings
-	float pidduties[NumPIDJoints]; //!< duty cycles - -1 means the motor is trying to move full power in negative direction, 1 means full power in positive direction, in practice, these values stay rather small - 0.15 is significant force.
+	float outputs[NumOutputs];     //!< last sensed positions of joints, for ears (or other future "boolean joints"), x<.5 is up, x>=.5 is down; indexes (aka offsets) are defined in the target model's namespace (e.g. ERS210Info)
+	float buttons[NumButtons];     //!< magnitude is pressure for some, 0/1 for others; indexes are defined in the ButtonOffset_t of the target model's namespace (e.g. ERS210Info::ButtonOffset_t)
+	float sensors[NumSensors];     //!< IR, Accel, Thermo, Power stuff; indexes are defined in SensorOffset_t of the target model's namespace (e.g. ERS210Info::SensorOffset_t)
+	float pids[NumPIDJoints][3];   //!< current PID settings (same ordering as the #outputs)
+	float pidduties[NumPIDJoints]; //!< duty cycles - -1 means the motor is trying to move full power in negative direction, 1 means full power in positive direction, in practice, these values stay rather small - 0.15 is significant force. (same ordering as the #outputs)
 	
-	float vel_x; //!< the current, egocentric rate of forward travel
-	float vel_y; //!< the current, egocentric rate of sideways (leftward is positive) travel
-	float vel_a; //!< the current, egocentric rate of rotational (counterclockwise is positive) travel
+	float vel_x; //!< the current, egocentric rate of forward locomotion
+	float vel_y; //!< the current, egocentric rate of sideways (leftward is positive) locomotion
+	float vel_a; //!< the current, egocentric rate of rotational (counterclockwise is positive) locomotion
 	unsigned int vel_time; //!< the time at which we began moving along the current velocity vector
 
 	unsigned int robotStatus;       //!< bitmask, see OPENR/OPower.h
 	unsigned int batteryStatus;     //!< bitmask, see OPENR/OPower.h
-	unsigned int powerFlags[PowerSourceID::NumPowerSIDs]; //!< bitmasks of similarly-grouped items from previous two masks, corresponds to the PowerSourceID_t's
+	unsigned int powerFlags[PowerSourceID::NumPowerSIDs]; //!< bitmasks of similarly-grouped items from previous two masks, corresponds to the PowerSourceID::PowerSourceID_t's
 
 	unsigned int button_times[NumButtons]; //!< value is time of current press, 0 if not down
 	
@@ -135,16 +149,19 @@ public:
 #endif
 
 	//! bitmask corresponding to OPENR::GetRobotDesign()
-	/*! This allows you to efficiently test different combinations, like any
-	 *  2x0 model vs. any 7 model or any 3xx model (when/if the 3xx's are supported).\n
-	 *  Testing this will give more accurate feedback as to whether features
-	 *  exist than checking RobotInfo values - to achieve dual booting, RobotInfo
-	 *  may, for instance, tell you there are two ears, but if you're running on a
-	 *  220 the value you set them to will be ignored */
+	/*! This allows you to efficiently test different combinations, like
+	 *  any 2x0 model vs. any 7 model or any 3xx model (when/if the
+	 *  3xx's are supported).
+	 *
+	 *  Testing this will give more accurate feedback as to whether
+	 *  features exist than checking RobotInfo values - to achieve dual
+	 *  booting, RobotInfo may, for instance, tell you there are two
+	 *  ears, but if you're running on a 220 the value you set them to
+	 *  will be ignored */
 	unsigned int robotDesign;  
-	static const unsigned int ERS210Mask=1<<0;  //!< use this to test for ERS210 features
-	static const unsigned int ERS220Mask=1<<1;  //!< use this to test for ERS220 features
-	static const unsigned int ERS7Mask=1<<2;  //!< use this to test for ERS220 features
+	static const unsigned int ERS210Mask=1<<0;  //!< use this to test for ERS-210 features
+	static const unsigned int ERS220Mask=1<<1;  //!< use this to test for ERS-220 features
+	static const unsigned int ERS7Mask=1<<2;  //!< use this to test for ERS-7 features
 
 protected:
 	unsigned int curtime; //!< set by read(OSensorFrameVectorData& sensor, EventRouter* er) for chkEvent() so each call doesn't have to
@@ -153,7 +170,8 @@ protected:
 	void chkEvent(EventRouter* er, unsigned int off, float newval, const char* name);
 
 	//! sets the names of the flags that will be generating events
-	/*! note that this function does not actually do the event posting */
+	/*! note that this function does not actually do the event posting,
+	 *  unlike chkEvent() */
 	void chkPowerEvent(unsigned int sid, unsigned int cur, unsigned int mask, const char* name, 
 										 std::string actname[PowerSourceID::NumPowerSIDs],
 										 std::string dename[PowerSourceID::NumPowerSIDs],
@@ -192,10 +210,10 @@ extern WorldState * state; //!< the global state object, is a shared memory regi
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.24 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2004/01/19 20:36:48 $
+ * $Date: 2004/02/09 22:45:28 $
  */
 
 #endif
