@@ -12,14 +12,9 @@
 #include "Shared/debuget.h"
 
 CDTGenerator::CDTGenerator(unsigned int numRawLayers, unsigned int numCalcLayers, EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid)
-	: FilterBankGenerator("CDTGenerator",numCalcLayers,NUM_CHANNELS,gid,sid,EventBase::visSegmentEGID,mysid), numRealLayers(numRawLayers), layers(NULL), imageInfos(NULL)
+	: FilterBankGenerator("CDTGenerator",gid,sid,EventBase::visSegmentEGID,mysid), numRealLayers(numRawLayers), layers(NULL), imageInfos(NULL)
 {
-	setNumImages(numLayers,numChannels);
-}
-
-CDTGenerator::~CDTGenerator() {
-	freeCaches();
-	destruct();
+	setNumImages(numCalcLayers,NUM_CHANNELS);
 }
 
 /*! The const casts in this function are regretable but necessary
@@ -153,6 +148,8 @@ CDTGenerator::freeCaches() {
 
 void
 CDTGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels) {
+	if(nLayers==numLayers && nChannels==numChannels)
+		return;
 	FilterBankGenerator::setNumImages(nLayers,nChannels);
 	layers=new unsigned char*[numLayers];
 	imageInfos=new const OFbkImageInfo*[numLayers];
@@ -236,9 +233,9 @@ CDTGenerator::destruct() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:59 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
