@@ -1,4 +1,5 @@
 #include "FilterBankGenerator.h"
+#include "Events/FilterBankEvent.h"
 #include "Events/EventRouter.h"
 
 unsigned char *
@@ -30,6 +31,19 @@ FilterBankGenerator::invalidateCaches() {
 	    imageValids[i][j]=false;
 }
 
+void
+FilterBankGenerator::processEvent(const EventBase & event) {
+	const FilterBankEvent& fbkevent=dynamic_cast<const FilterBankEvent& >(event);
+	src=fbkevent.getSource();
+	frameNumber=src->getFrameNumber();
+	setNumImages(src->getNumLayers(),src->getNumChannels());
+	if(numLayers>0 && (src->getWidth(numLayers-1)!=getWidth(numLayers-1) || src->getHeight(numLayers-1)!=getHeight(numLayers-1))) {
+		ASSERT(widths[numLayers-1]==0,"Strange, the image dim changed after initial setting" << widths[numLayers-1] << ' ' << heights[numLayers-1]);
+		setDimensions();
+	}
+	invalidateCaches();
+	framesProcessed++;
+}
 
 unsigned int FilterBankGenerator::getBinSize() const {
 	unsigned int used=0;
@@ -76,6 +90,8 @@ unsigned int FilterBankGenerator::SaveBuffer(char buf[], unsigned int len) const
 
 void
 FilterBankGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels) {
+	if(nLayers==numLayers && nChannels==numChannels)
+		return;
 	freeCaches();
 	destruct();
 	numLayers=nLayers;
@@ -102,6 +118,16 @@ FilterBankGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels)
 	}
 }
 
+void
+FilterBankGenerator::setDimensions() {
+	if(src==NULL)
+		return;
+	for(unsigned int i=0; i<numLayers; i++) {
+		widths[i]=src->getWidth(i);
+		heights[i]=src->getHeight(i);
+	}
+}
+
 void
 FilterBankGenerator::destruct() {
 	delete [] widths;
@@ -132,9 +158,9 @@ FilterBankGenerator::destruct() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/02/05 19:11:41 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
