@@ -111,33 +111,35 @@
  */
 class FilterBankGenerator : public EventGeneratorBase, public LoadSave {
 public:
-	//! constructor, calls setNumImages(1,1)
+	//! constructor
 	FilterBankGenerator()
-		: EventGeneratorBase(), numLayers(0), numChannels(0), widths(NULL), heights(NULL), skips(NULL), strides(NULL), increments(NULL), images(NULL), imageValids(NULL), selectedSaveLayer(0), selectedSaveChannel(0), frameNumber(0), framesProcessed(0)
-	{
-		setNumImages(1,1);
-	}
+		: EventGeneratorBase(), src(NULL), numLayers(0), numChannels(0), widths(NULL), heights(NULL), skips(NULL), strides(NULL), increments(NULL), images(NULL), imageValids(NULL), selectedSaveLayer(0), selectedSaveChannel(0), frameNumber(0), framesProcessed(0)
+	{	}
 
 	//! constructor
-	FilterBankGenerator(unsigned int layers, unsigned int channels)
-		: EventGeneratorBase(), numLayers(0), numChannels(0), widths(NULL), heights(NULL), skips(NULL), strides(NULL), increments(NULL), images(NULL), imageValids(NULL), selectedSaveLayer(0), selectedSaveChannel(0), frameNumber(0), framesProcessed(0)
-	{
-		setNumImages(layers,channels);
-	}
-
-	//! constructor
-	FilterBankGenerator(const std::string& name,unsigned int layers, unsigned int channels, EventBase::EventGeneratorID_t srcgid, unsigned int srcsid, EventBase::EventGeneratorID_t mgid, unsigned int msid)
-		: EventGeneratorBase(name,mgid,msid,srcgid,srcsid), numLayers(0), numChannels(0), widths(NULL), heights(NULL), skips(NULL), strides(NULL), increments(NULL), images(NULL), imageValids(NULL), selectedSaveLayer(0), selectedSaveChannel(0), frameNumber(0), framesProcessed(0)
-	{
-		setNumImages(layers,channels);
-	}
+	FilterBankGenerator(const std::string& name,EventBase::EventGeneratorID_t srcgid, unsigned int srcsid, EventBase::EventGeneratorID_t mgid, unsigned int msid)
+		: EventGeneratorBase(name,mgid,msid,srcgid,srcsid), src(NULL), numLayers(0), numChannels(0), widths(NULL), heights(NULL), skips(NULL), strides(NULL), increments(NULL), images(NULL), imageValids(NULL), selectedSaveLayer(0), selectedSaveChannel(0), frameNumber(0), framesProcessed(0)
+	{ }
 
 	//! destructor
-	~FilterBankGenerator() {
+	/*! Your own subclasses should also have destructors which call
+	 *  freeCaches() and destruct().  Otherwise, if you override these
+	 *  functions to delete any custom memory you allocate, those
+	 *  implementations won't be called by this destructor... a
+	 *  destructor ignores virtual functions, only calls at its own
+	 *  class level.\n
+	 *  So it really doesn't matter if you aren't allocating any extra
+	 *  memory other than what's in the image cache, but it's still good
+	 *  form just in case you add stuff later so you won't forget and
+	 *  leak memory everywhere */
+	virtual ~FilterBankGenerator() {
 		freeCaches();
 		destruct();
 	}
 
+	//! returns the generator this is receiving its events from (or the last one anyway)
+	virtual const FilterBankGenerator * getSourceGenerator() const { return src; }
+
 	//! returns the number of image layers (e.g. different resolutions available)
 	virtual unsigned int getNumLayers() const { return numLayers; }
 
@@ -179,8 +181,15 @@ public:
 	/*! You probably want to call this right before you send the FilterBankEvent */
 	virtual void invalidateCaches();
 
-	//! default implementation ignore events, just so you don't have to define it if you don't receive events
-	virtual void processEvent(const EventBase & /*event*/) {}
+	//! default implementation does a few common housekeeping chores for you - probably should just take a look at its code
+	/*! It doesn't throw any events for you - that's probably the main
+	 *  reason you'd still want to override it\n
+	 *  Also, if your class has a set number of layers or channels - for
+	 *  instance, always 1 channel like InterleavedYUVGenerator, you
+	 *  should override setNumImages() to enforce that constraint by
+	 *  throwing away the appropriate argument and passing the your own
+	 *  value to the superclass implementation.*/
+	virtual void processEvent(const EventBase & event);
 	
 	//!@name LoadSave interface
 
@@ -208,9 +217,16 @@ protected:
 	 *  some pubic accessor functions which call this.  In general, the
 	 *  included subclasses should be able to handle being resized, but
 	 *  there's no reason to do so since the system won't be changing
-	 *  its available resolutions at run time. */
+	 *  its available resolutions at run time. 
+	 *
+	 *  The default implementation is a no-op if(numLayers==nLayers && numChannels==nChannels)
+	 */
 	virtual void setNumImages(unsigned int nLayers, unsigned int nChannels);
 
+	//! resets width and height parameters to that of the #src
+	/*! You'll probably want to override this to also set #skip and #stride */
+	virtual void setDimensions();
+	
 	//! create new image data storage area for the cache - this called by getImage() only when the corresponding entry in images is NULL
 	/*! You should return the pointer you want stored in images to be
 	 *  returned by any calls to getFirstRow.  Interpretation of the
@@ -225,6 +241,8 @@ protected:
 	//! deletes the arrays
 	virtual void destruct();
 
+	const FilterBankGenerator * src; //!< the generator of the last FilterBankEvent received
+
 	unsigned int numLayers;   //!< current number of layers available
 	unsigned int numChannels; //!< current number of channels available
 
@@ -252,7 +270,10 @@ protected:
 	 *  up, so there's no way they can be processed.
 	 */
 	unsigned int frameNumber; 
-	unsigned int framesProcessed; //!< subclasses should increment this any time they make a new filter bank available (probably by throwing an event)
+
+	//! subclasses should increment this any time they make a new filter bank available
+	/*! this is automatically incremented if you use the FilterBankGenerator::processEvent() */
+	unsigned int framesProcessed; 
 
 private:
 	FilterBankGenerator(const FilterBankGenerator& fbk); //!< don't call
@@ -264,10 +285,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:48 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
 #endif
