@@ -7,38 +7,16 @@
 #include "Shared/debuget.h"
 
 InterleavedYUVGenerator::InterleavedYUVGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid)
-	: FilterBankGenerator("InterleavedYUVGenerator",0,1,gid,sid,EventBase::visInterleaveEGID,mysid), src(NULL), srcYChan(0), srcUChan(1), srcVChan(2)
-{
-	setNumImages(numLayers,numChannels);
-}
+	: FilterBankGenerator("InterleavedYUVGenerator",gid,sid,EventBase::visInterleaveEGID,mysid), srcYChan(0), srcUChan(1), srcVChan(2)
+{ }
 
 InterleavedYUVGenerator::InterleavedYUVGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid, unsigned int syc, unsigned int suc, unsigned int svc)
-	: FilterBankGenerator("InterleavedYUVGenerator",0,1,gid,sid,EventBase::visInterleaveEGID,mysid), src(NULL), srcYChan(syc), srcUChan(suc), srcVChan(svc)
-{
-	setNumImages(numLayers,numChannels);
-}
-
-/*
-InterleavedYUVGenerator::~InterleavedYUVGenerator() {
-	freeCaches();
-	destruct();
-}
-*/
+	: FilterBankGenerator("InterleavedYUVGenerator",gid,sid,EventBase::visInterleaveEGID,mysid), srcYChan(syc), srcUChan(suc), srcVChan(svc)
+{ }
 
 void
 InterleavedYUVGenerator::processEvent(const EventBase& event) {
-	const FilterBankEvent& fbkevent=dynamic_cast<const FilterBankEvent& >(event);
-	src=fbkevent.getSource();
-	frameNumber=src->getFrameNumber();
-	if(src->getNumLayers()!=numLayers || src->getNumChannels()!=numChannels)
-		setNumImages(src->getNumLayers(),1);
-	if(src->getWidth(numLayers-1)!=getWidth(numLayers-1)) {
-		ASSERT(widths[numLayers-1]==0,"Strange, the image width changed after initial setting" << widths[numLayers-1]);
-		setDimensions();
-	}
-
-	invalidateCaches();
-	framesProcessed++;
+	FilterBankGenerator::processEvent(event);
 	erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID()));
 }
 
@@ -46,10 +24,7 @@ unsigned int
 InterleavedYUVGenerator::getBinSize() const {
 	unsigned int used=FilterBankGenerator::getBinSize();
 	used+=strlen("InterleavedYUVImage")+LoadSave::stringpad;
-	//if(selectedSaveChannel==CHAN_YUV)
 	used+=widths[selectedSaveLayer]*heights[selectedSaveLayer]*3;
-	//else
-	//used+=widths[selectedSaveLayer]*heights[selectedSaveLayer];
 	return used;
 }
 
@@ -66,7 +41,6 @@ InterleavedYUVGenerator::LoadBuffer(const char buf[], unsigned int len) {
 		serr->printf("Unhandled image type for InterleavedYUVGenerator: %s",tmp.c_str());
 		return 0;
 	} else {
-		//if(selectedSaveChannel==CHAN_YUV) {
 		used=widths[selectedSaveLayer]*heights[selectedSaveLayer]*3;
 		if(used>len)
 			return 0;
@@ -78,26 +52,6 @@ InterleavedYUVGenerator::LoadBuffer(const char buf[], unsigned int len) {
 		memcpy(img,buf,used);
 		len-=used; buf+=used;
 		imageValids[selectedSaveLayer][selectedSaveChannel]=true;
-		/*
-		} else {
-			used=widths[selectedSaveLayer]*heights[selectedSaveLayer];
-			if(used>len)
-				return 0;
-			unsigned char* img=getImage(selectedSaveLayer,selectedSaveChannel);
-			if(img==NULL)
-				return 0;
-			unsigned int inc=getIncrement(selectedSaveLayer);
-			for(unsigned int y=0; y<heights[selectedSaveLayer]; y++) {
-				unsigned char* const rowend=img+widths[selectedSaveLayer]*inc;
-				while(img!=rowend) {
-					*img=*buf++;
-					img+=inc;
-				}
-				img+=getSkip(selectedSaveLayer);
-			}
-			len-=used; buf+=used;
-		}
-		*/
 		return origlen-len;	
 	}
 }
@@ -111,7 +65,6 @@ InterleavedYUVGenerator::SaveBuffer(char buf[], unsigned int len) const {
 	if(0==(used=encode("InterleavedYUVImage",buf,len))) return 0;
 	len-=used; buf+=used;
 	
-	//if(selectedSaveChannel==CHAN_YUV) {
 	used=widths[selectedSaveLayer]*heights[selectedSaveLayer]*3;
 	if(used>len)
 		return 0;
@@ -120,78 +73,25 @@ InterleavedYUVGenerator::SaveBuffer(char buf[], unsigned int len) const {
 		return 0;
 	memcpy(buf,img,used);
 	len-=used;
-	/*
-	} else {
-		used=widths[selectedSaveLayer]*heights[selectedSaveLayer];
-		if(used>len)
-			return 0;
-		unsigned char* img=getImage(selectedSaveLayer,selectedSaveChannel);
-		if(img==NULL)
-			return 0;
-		unsigned int inc=getIncrement(selectedSaveLayer);
-		for(unsigned int y=0; y<heights[selectedSaveLayer]; y++) {
-			unsigned char* const rowend=img+widths[selectedSaveLayer]*inc;
-			while(img!=rowend) {
-				*buf++=*img;
-				img+=inc;
-			}
-			img+=getSkip(selectedSaveLayer);
-		}
-		len-=used; buf+=used;
-	}
-	*/
 	return origlen-len;
 }
 
-/*
-void 
-InterleavedYUVGenerator::freeCaches() {
-	for(unsigned int i=0; i<numLayers; i++) {
-		for(unsigned int j=0; j<numChannels-1; j++) {
-			images[i][j]=NULL;
-			imageValids[i][j]=false;
-		}
-	}
-	FilterBankGenerator::freeCaches();
-}
-*/
-
 void
 InterleavedYUVGenerator::setDimensions() {
-	for(unsigned int i=0; i<numLayers; i++) {
-		widths[i]=src->getWidth(i);
-		heights[i]=src->getHeight(i);
-		skips[i]=0;
+	FilterBankGenerator::setDimensions();
+	for(unsigned int i=0; i<numLayers; i++)
 		strides[i]=widths[i]*3;
-	}	
 }
 
 void
 InterleavedYUVGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels) {
-	ASSERT(nChannels==1,"we can only handle a single channel...");
-	FilterBankGenerator::setNumImages(nLayers,nChannels);
+	if(nLayers==numLayers && nChannels==numChannels)
+		return;
+	FilterBankGenerator::setNumImages(nLayers,1);
 	for(unsigned int res=0; res<numLayers; res++)
 		increments[res]=3;
 }
 
-/*
-unsigned char *
-InterleavedYUVGenerator::createImageCache(unsigned int layer, unsigned int chan) const {
-	unsigned char* yuv=new unsigned char[widths[layer]*heights[layer]*3];
-	for(unsigned int i=0; i<numChannels-1; i++) {
-		ASSERT(images[layer][i]==NULL,"memory leak?");
-		images[layer][i]=yuv+i;
-	}
-	ASSERT(images[layer][CHAN_YUV]==NULL,"memory leak?");
-	images[layer][CHAN_YUV]=yuv;
-	if(chan==CHAN_YUV) {
-		return yuv;
-	} else {
-		return yuv+chan;
-	}
-}
-*/
-
 unsigned char *
 InterleavedYUVGenerator::createImageCache(unsigned int layer, unsigned int /*chan*/) const {
 	return new unsigned char[widths[layer]*heights[layer]*3];
@@ -227,9 +127,9 @@ InterleavedYUVGenerator::calcImage(unsigned int layer, unsigned int chan) const
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/01/16 07:39:50 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
