@@ -39,6 +39,12 @@ public:
 	//! constructor, you can pass which channels to interleave
 	InterleavedYUVGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid, unsigned int syc, unsigned int suc, unsigned int svc);
 
+	//! destructor
+	virtual ~InterleavedYUVGenerator() {
+		freeCaches();
+		destruct();
+	}
+
 	static const unsigned int CHAN_YUV=0; //!< so you can refer to the YUV channel symbolically.
 
 	static std::string getClassDescription() { return "Converts a FilterBankGenerator's data into interleaved format"; }
@@ -54,11 +60,10 @@ public:
 
 protected:
 	virtual void setNumImages(unsigned int nLayers, unsigned int nChannels);
-	virtual void setDimensions(); //!< resets width, height, skip and stride parameters
+	virtual void setDimensions(); //!< resets stride parameter (to correspond to width*3 from FilterBankGenerator::setDimensions())
 	virtual unsigned char * createImageCache(unsigned int layer, unsigned int chan) const;
 	virtual void calcImage(unsigned int layer, unsigned int chan) const;
 
-	const FilterBankGenerator * src; //!< the generator of the last FilterBankEvent received
 	unsigned int srcYChan; //!< the channel of the source's Y channel
 	unsigned int srcUChan; //!< the channel of the source's U channel
 	unsigned int srcVChan; //!< the channel of the source's V channel
@@ -73,10 +78,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:48 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
 #endif
