@@ -14,10 +14,8 @@
 #include "Shared/debuget.h"
 
 JPEGGenerator::JPEGGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid)
-	: FilterBankGenerator("JPEGGenerator",0,0,gid,sid,EventBase::visJPEGEGID,mysid), src(NULL), srcMode(SRC_AUTO), curMode(SRC_AUTO), bytesUsed(NULL), cinfo(), jerr(), quality(-1U)
+	: FilterBankGenerator("JPEGGenerator",gid,sid,EventBase::visJPEGEGID,mysid), srcMode(SRC_AUTO), curMode(SRC_AUTO), bytesUsed(NULL), cinfo(), jerr(), quality(-1U)
 {
-	setNumImages(numLayers,numChannels);
-
 	// We set the err object before we create the compress...  the idea
 	// is if the creation fails, we can still get the error as to why it
 	// failed.
@@ -26,10 +24,8 @@ JPEGGenerator::JPEGGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid
 }
 
 JPEGGenerator::JPEGGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid, src_mode_t mode)
-	: FilterBankGenerator("JPEGGenerator",0,0,gid,sid,EventBase::visJPEGEGID,mysid), src(NULL), srcMode(mode), curMode(SRC_AUTO), bytesUsed(NULL), cinfo(), jerr(), quality(-1U)
+	: FilterBankGenerator("JPEGGenerator",gid,sid,EventBase::visJPEGEGID,mysid), srcMode(mode), curMode(SRC_AUTO), bytesUsed(NULL), cinfo(), jerr(), quality(-1U)
 {
-	setNumImages(numLayers,numChannels);
-
 	// We set the err object before we create the compress...  the idea
 	// is if the creation fails, we can still get the error as to why it
 	// failed.
@@ -50,24 +46,13 @@ JPEGGenerator::~JPEGGenerator() {
  */
 void
 JPEGGenerator::processEvent(const EventBase& event) {
-	const FilterBankEvent& fbkevent=dynamic_cast<const FilterBankEvent& >(event);
-	src=fbkevent.getSource();
-	frameNumber=src->getFrameNumber();
+	FilterBankGenerator::processEvent(event);
 	if(getSourceMode()==SRC_AUTO) { //if not auto, curMode was already set when srcMode was set
 		if(dynamic_cast<const InterleavedYUVGenerator*>(src)!=NULL)
 			curMode=SRC_COLOR;
 		else
 			curMode=SRC_GRAYSCALE;
 	}
-	if(src->getNumLayers()!=numLayers || src->getNumChannels()!=numChannels)
-		setNumImages(src->getNumLayers(),src->getNumChannels());
-	if(src->getWidth(numLayers-1)!=getWidth(numLayers-1)) {
-		ASSERT(widths[numLayers-1]==0,"Strange, the image width changed after initial setting" << widths[numLayers-1]);
-		setDimensions();
-	}
-
-	invalidateCaches();
-	framesProcessed++;
 	erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID()));
 }
 
@@ -150,18 +135,13 @@ JPEGGenerator::SaveBuffer(char buf[], unsigned int len) const {
 	return origlen-len;
 }
 
-void
-JPEGGenerator::setDimensions() {
-	for(unsigned int i=0; i<numLayers; i++) {
-		widths[i]=src->getWidth(i);
-		heights[i]=src->getHeight(i);
-		strides[i]=skips[i]=0;
-	}	
-}
-
 void
 JPEGGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels) {
+	if(nLayers==numLayers && nChannels==numChannels)
+		return;
 	FilterBankGenerator::setNumImages(nLayers,nChannels);
+	for(unsigned int i=0; i<numLayers; i++)
+		strides[i]=skips[i]=0;
 	bytesUsed=new unsigned int*[numLayers];
 	for(unsigned int res=0; res<numLayers; res++) {
 		increments[res]=3;
@@ -259,9 +239,9 @@ JPEGGenerator::destruct() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/01/19 07:56:41 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
