@@ -83,12 +83,10 @@ public:
 
 protected:
 	virtual void setNumImages(unsigned int nLayers, unsigned int nChannels);
-	virtual void setDimensions(); //!< resets width, height, skip and stride parameters
 	virtual unsigned char * createImageCache(unsigned int layer, unsigned int chan) const;
 	virtual void calcImage(unsigned int layer, unsigned int chan) const;
 	virtual void destruct();
 
-	const FilterBankGenerator * src; //!< the generator of the last FilterBankEvent received
 	src_mode_t srcMode;   //!< how to interpret source channel of next filter bank event
 	src_mode_t curMode;   //!< how to interpret getImage's current image
 
@@ -109,10 +107,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/01/19 07:56:41 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
 #endif
