@@ -7,29 +7,13 @@
 #include "Shared/debuget.h"
 
 RLEGenerator::RLEGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid)
-	: FilterBankGenerator("RLEGenerator",0,0,gid,sid,EventBase::visRLEEGID,mysid), src(NULL), numRuns(NULL), maxRuns(NULL)
-{
-	setNumImages(numLayers,numChannels);
-}
-
-RLEGenerator::~RLEGenerator() {
-	freeCaches();
-	destruct();
-}
+	: FilterBankGenerator("RLEGenerator",gid,sid,EventBase::visRLEEGID,mysid), numRuns(NULL), maxRuns(NULL)
+{ }
 
 void
 RLEGenerator::processEvent(const EventBase& event) {
-	const FilterBankEvent& fbkevent=dynamic_cast<const FilterBankEvent& >(event);
-	src=fbkevent.getSource();
-	frameNumber=src->getFrameNumber();
-	if(src->getNumLayers()!=numLayers || src->getNumChannels()!=numChannels)
-		setNumImages(src->getNumLayers(),src->getNumChannels());
-	if(src->getWidth(numLayers-1)!=getWidth(numLayers-1))
-		setDimensions();
-
-	invalidateCaches();
-	framesProcessed++;
-	if(const SegmentedColorFilterBankEvent * segsrc=dynamic_cast<const SegmentedColorFilterBankEvent *>(&fbkevent))
+	FilterBankGenerator::processEvent(event);
+	if(const SegmentedColorFilterBankEvent * segsrc=dynamic_cast<const SegmentedColorFilterBankEvent *>(&event))
 		erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),*segsrc));
 	else
 		erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID()));
@@ -114,16 +98,16 @@ RLEGenerator::SaveBuffer(char buf[], unsigned int len) const {
 
 void
 RLEGenerator::setDimensions() {
-	for(unsigned int i=0; i<numLayers; i++) {
-		widths[i]=src->getWidth(i);
-		heights[i]=src->getHeight(i);
+	FilterBankGenerator::setDimensions();
+	for(unsigned int i=0; i<numLayers; i++)
 		maxRuns[i]=calcExpMaxRuns(i);
-	}	
 }
 
 void
 RLEGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels) {
-	FilterBankGenerator::setNumImages(nLayers,nChannels);
+	if(nLayers==numLayers && nChannels==numChannels)
+		return;
+	FilterBankGenerator::setNumImages(nLayers,nChannels); //calls destruct()...
 	maxRuns=new unsigned int[numLayers];
 	numRuns=new unsigned int*[numLayers];
 	for(unsigned int i=0; i<numLayers; i++) {
@@ -163,9 +147,9 @@ RLEGenerator::destruct() {
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/05 02:37:09 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
