@@ -68,8 +68,12 @@ public:
 	
 	//! constructor
 	RLEGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid);
+	
 	//! destructor
-	virtual ~RLEGenerator();
+	virtual ~RLEGenerator() {
+		freeCaches();
+		destruct();
+	}
 
 	static std::string getClassDescription() { return "Compresses a FilterBankGenerator's channels using run length encoding"; }
 
@@ -87,9 +91,6 @@ public:
 	//! returns a specific run of the specified image
 	virtual const run& getRun(unsigned int layer, unsigned int chan, unsigned int i) const { return reinterpret_cast<const run*>(getImage(layer,chan))[i]; }
 	
-	//! returns the generator this is receiving its events from (or the last one anyway)
-	virtual FilterBankGenerator * getSourceGenerator() const { return src; }
-
 protected:
 	static const unsigned int MIN_EXP_RUN_LENGTH=8; //!< The expected minimum average length of each run
 	static const unsigned int XMIT_BYTES_PER_RUN=sizeof(cmap_t)+sizeof(short)+sizeof(short); //!< number of bytes needed to send each run
@@ -102,8 +103,6 @@ protected:
 	//! uses a heuristic to predict the maximum number of runs expected per layer
 	unsigned int calcExpMaxRuns(unsigned int layer) const { return getWidth(layer)*getHeight(layer)/MIN_EXP_RUN_LENGTH; }
 
-	FilterBankGenerator * src; //!< the generator of the last FilterBankEvent received
-
 	unsigned int ** numRuns; //!< a matrix of ints, holds the number of used runs for each image
 	unsigned int * maxRuns; //!< the maximum number of runs possible for each layer
 
@@ -118,10 +117,10 @@ private:
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:48 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
 #endif
