@@ -12,14 +12,9 @@
 #include "Shared/debuget.h"
 
 RawCameraGenerator::RawCameraGenerator(unsigned int numRawLayers, unsigned int numCalcLayers, EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid)
-	: FilterBankGenerator("RawCameraGenerator",numCalcLayers,NUM_CHANNELS,gid,sid,EventBase::visRawCameraEGID,mysid), numRealLayers(numRawLayers), layers(NULL), imageInfos(NULL)
+	: FilterBankGenerator("RawCameraGenerator",gid,sid,EventBase::visRawCameraEGID,mysid), numRealLayers(numRawLayers), layers(NULL), imageInfos(NULL)
 {
-	setNumImages(numLayers,numChannels);
-}
-
-RawCameraGenerator::~RawCameraGenerator() {
-	freeCaches();
-	destruct();
+	setNumImages(numCalcLayers,NUM_CHANNELS);
 }
 
 /*! The const casts in this function are regretable but necessary
@@ -226,6 +221,8 @@ RawCameraGenerator::freeCaches() {
 
 void
 RawCameraGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels) {
+	if(nLayers==numLayers && nChannels==numChannels)
+		return;
 	FilterBankGenerator::setNumImages(nLayers,nChannels);
 	layers=new unsigned char*[numLayers];
 	imageInfos=new const OFbkImageInfo*[numLayers];
@@ -341,20 +338,20 @@ RawCameraGenerator::upsampleImage(channel_id_t chan) const {
 
 	unsigned char * cur=images[dblLayer][chan];
 	ASSERTRET(cur!=NULL,"destination layer is NULL");
-	unsigned char * src=getImage(srcLayer,chan);
-	ASSERTRET(cur!=NULL,"source layer is NULL");
+	unsigned char * orig=getImage(srcLayer,chan);
+	ASSERTRET(orig!=NULL,"source layer is NULL");
 
 	unsigned char * const imgend=cur+width*height;
 	while(cur!=imgend) {
 		unsigned char * const row=cur;
 		unsigned char * const rowend=cur+width;
 		while(cur!=rowend) {
-			*cur++=*src;
-			*cur++=*src++;
+			*cur++=*orig;
+			*cur++=*orig++;
 		}
 		memcpy(cur,row,width);
 		cur+=width;
-		src+=getSkip(srcLayer);
+		orig+=getSkip(srcLayer);
 	}
 }
 
@@ -425,9 +422,9 @@ RawCameraGenerator::reconstructImage() const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2004/02/06 00:06:31 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
