@@ -30,7 +30,10 @@ public:
 	RawCameraGenerator(unsigned int numRawLayers, unsigned int numCalcLayers, EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid);
 
 	//! destructor
-	virtual ~RawCameraGenerator();
+	virtual ~RawCameraGenerator() {
+		freeCaches();
+		destruct();
+	}
 
 	static std::string getClassDescription() { return "Translates OFbkImageVectorData objects from the system into a slightly more accessible FilterBankEvent for further processing"; }
 
@@ -112,10 +115,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:48 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
 #endif
