@@ -8,15 +8,8 @@
 #include "Shared/debuget.h"
 
 RegionGenerator::RegionGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid)
-	: FilterBankGenerator("RegionGenerator",0,0,gid,sid,EventBase::visRegionEGID,mysid), src(NULL), srcNumColors(0), srcColors(0), regions(NULL)
-{
-	setNumImages(numLayers,numChannels);
-}
-
-RegionGenerator::~RegionGenerator() {
-	freeCaches();
-	destruct();
-}
+	: FilterBankGenerator("RegionGenerator",gid,sid,EventBase::visRegionEGID,mysid), srcNumColors(0), srcColors(0), regions(NULL)
+{ }
 
 void
 RegionGenerator::freeCaches() {
@@ -30,9 +23,7 @@ RegionGenerator::freeCaches() {
 
 void
 RegionGenerator::processEvent(const EventBase& event) {
-	const FilterBankEvent& fbkevent=dynamic_cast<const FilterBankEvent& >(event);
-	src=fbkevent.getSource();
-	frameNumber=src->getFrameNumber();
+	FilterBankGenerator::processEvent(event);
 	const RLEGenerator * rle=dynamic_cast<const RLEGenerator*>(src);
 	if(NULL==rle) {
 		serr->printf("RegionGenerator's event %s is not from RLEGenerator\n",event.getName().c_str());
@@ -47,13 +38,6 @@ RegionGenerator::processEvent(const EventBase& event) {
 		freeCaches();
 	srcNumColors=segev->getNumColors();
 	srcColors=segev->getColors();
-	if(src->getNumLayers()!=numLayers || src->getNumChannels()!=numChannels)
-		setNumImages(src->getNumLayers(),src->getNumChannels());
-	if(src->getWidth(numLayers-1)!=getWidth(numLayers-1))
-		setDimensions();
-
-	invalidateCaches();
-	framesProcessed++;
 	erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),*segev));
 }
 
@@ -192,6 +176,8 @@ RegionGenerator::SaveBuffer(char buf[], unsigned int len) const {
 
 void
 RegionGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels) {
+	if(nLayers==numLayers && nChannels==numChannels)
+		return;
 	FilterBankGenerator::setNumImages(nLayers,nChannels);
 	regions = new region**[numLayers];
 	for(unsigned int i=0; i<numLayers; i++) {
@@ -201,15 +187,6 @@ RegionGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels) {
 	}
 }
 
-
-void
-RegionGenerator::setDimensions() {
-	for(unsigned int i=0; i<numLayers; i++) {
-		widths[i]=src->getWidth(i);
-		heights[i]=src->getHeight(i);
-	}	
-}
-
 unsigned char *
 RegionGenerator::createImageCache(unsigned int layer, unsigned int chan) const {
 	//this is where we'll store the linked list of regions for this image
@@ -260,9 +237,9 @@ RegionGenerator::destruct() {
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/05 02:46:41 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
