@@ -32,8 +32,12 @@ public:
 	
 	//! constructor
 	RegionGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid);
+	
 	//! destructor
-	virtual ~RegionGenerator();
+	virtual ~RegionGenerator() {
+		freeCaches();
+		destruct();
+	}
 
 	static std::string getClassDescription() { return "Connects runs in an RLE compressed image into regions"; }
 
@@ -46,21 +50,15 @@ public:
 	virtual unsigned int LoadBuffer(const char buf[], unsigned int len);
 	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const;
 
-	//! returns the FilterBankGenerator this is receiving events from
-	virtual const FilterBankGenerator * getSourceGenerator() const { return src; }
-
 protected:
 	typedef SegmentedColorFilterBankEvent::color_class_state color_class_state; //!< use the same color info as SegmentedColorFilterBankEvent (since that's what's supplying the color info)
 	static const unsigned int MAX_REGIONS=176*144/16;  //!< maximum number of regions, value is from historical Vision sources
 
-	virtual void setDimensions(); //!< resets the width, height, skip and stride parameters
 	virtual void setNumImages(unsigned int nLayers, unsigned int nChannels);
 	virtual unsigned char * createImageCache(unsigned int layer, unsigned int chan) const;
 	virtual void calcImage(unsigned int layer, unsigned int chan) const;
 	virtual void destruct();
 
-	const FilterBankGenerator * src; //!< the generator of the last FilterBankEvent received
-	
 	unsigned int srcNumColors; //!< number of colors available (from src->src, which should be SegmentedColorGenerator...)
 	color_class_state * srcColors; //!< colors information (from src->src, which should be SegmentedColorGenerator...)
 	region *** regions; //!< data storage for region information
@@ -76,10 +74,10 @@ private:
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/02/05 02:46:41 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
 #endif
