@@ -7,35 +7,30 @@
 #include "Shared/debuget.h"
 
 SegmentedColorGenerator::SegmentedColorGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid)
-	: FilterBankGenerator("SegmentedColorGenerator",0,0,gid,sid,EventBase::visSegmentEGID,mysid), src(NULL), srcYChan(0), srcUChan(1), srcVChan(2), tmaps(), tmapNames(), numColors(0), colorNames()
-{
-	setNumImages(numLayers,numChannels);
-}
+	: FilterBankGenerator("SegmentedColorGenerator",gid,sid,EventBase::visSegmentEGID,mysid), srcYChan(0), srcUChan(1), srcVChan(2), tmaps(), tmapNames(), numColors(0), colorNames()
+{ }
 
 SegmentedColorGenerator::SegmentedColorGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid, unsigned int syc, unsigned int suc, unsigned int svc)
-	: FilterBankGenerator("SegmentedColorGenerator",0,0,gid,sid,EventBase::visSegmentEGID,mysid), src(NULL), srcYChan(syc), srcUChan(suc), srcVChan(svc), tmaps(), tmapNames(), numColors(0), colorNames()
-{
-	setNumImages(numLayers,numChannels);
-}
+	: FilterBankGenerator("SegmentedColorGenerator",gid,sid,EventBase::visSegmentEGID,mysid), srcYChan(syc), srcUChan(suc), srcVChan(svc), tmaps(), tmapNames(), numColors(0), colorNames()
+{ }
 
 SegmentedColorGenerator::~SegmentedColorGenerator() {
+	freeCaches();
+	destruct();
 	for(unsigned int i=0; i<tmaps.size(); i++)
 		delete [] tmaps[i];
-	// todo - i think we're leaking the color names memory
+
+	//hashmap::iterator it=colorNames.begin(); //not the way i'd like to iterate, but there seems to be a bug in the current hashmap implementation we're using...
+	//for(unsigned int i=0; i<colorNames.size(); it++,i++)
+	//free(const_cast<char*>(it->first));
+  //colorNames.clear();
+
+  colorNames.clear(); //we're leaking the memory of the names themselves...
 }
 
 void
 SegmentedColorGenerator::processEvent(const EventBase& event) {
-	const FilterBankEvent& fbkevent=dynamic_cast<const FilterBankEvent& >(event);
-	src=fbkevent.getSource();
-	frameNumber=src->getFrameNumber();
-	if(src->getNumLayers()!=numLayers || src->getNumChannels()!=numChannels)
-		setNumImages(src->getNumLayers(),1);
-	if(src->getWidth(numLayers-1)!=getWidth(numLayers-1))
-		setDimensions();
-
-	invalidateCaches();
-	framesProcessed++;
+	FilterBankGenerator::processEvent(event);
 	erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),this,getNumColors(),getColors(),&colorNames));
 }
 
@@ -63,8 +58,13 @@ SegmentedColorGenerator::loadThresholdMap(const std::string& tm_file) {
 
 bool
 SegmentedColorGenerator::loadColorInfo(const std::string& col_file) {
-	// todo - we're leaking the color names memory
-  colorNames.clear();
+	//hashmap::iterator it=colorNames.begin(); //not the way i'd like to iterate, but there seems to be a bug in the current hashmap implementation we're using...
+	//for(unsigned int i=0; i<colorNames.size(); it++,i++)
+	//free(const_cast<char*>(it->first));
+  //colorNames.clear();
+
+  colorNames.clear(); //we're leaking the memory of the names themselves...
+
   numColors=CMVision::LoadColorInformation(colors,MAX_COLORS,col_file.c_str(),colorNames);
   if(numColors > 0){
     sout->printf("  Loaded %d colors.\n",numColors);
@@ -187,12 +187,9 @@ SegmentedColorGenerator::decodeColors(const char buf[], unsigned int len) {
 
 void
 SegmentedColorGenerator::setDimensions() {
-	for(unsigned int i=0; i<numLayers; i++) {
-		widths[i]=src->getWidth(i);
-		heights[i]=src->getHeight(i);
-		skips[i]=0;
+	FilterBankGenerator::setDimensions();
+	for(unsigned int i=0; i<numLayers; i++)
 		strides[i]=widths[i];
-	}	
 }
 
 void
@@ -226,9 +223,9 @@ SegmentedColorGenerator::calcImage(unsigned int layer, unsigned int chan) const
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/01/16 07:39:51 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
