@@ -110,15 +110,13 @@ protected:
 	
 	//! ignores @a nChannels - the number of channels is always the number of loaded threshold maps
 	virtual void setNumImages(unsigned int nLayers, unsigned int nChannels);
-	virtual void setDimensions(); //!< sets width, height, skip, and stride parameters
+	virtual void setDimensions(); //!< sets stride parameter to width (as set by FilterBankGenerator::setDimensions())
 	virtual unsigned char * createImageCache(unsigned int layer, unsigned int chan) const;
 	virtual void calcImage(unsigned int layer, unsigned int chan) const;
 
-	const FilterBankGenerator * src; //!< the generator of the last FilterBankEvent received
 	unsigned int srcYChan; //!< the channel of the source's Y channel
 	unsigned int srcUChan; //!< the channel of the source's U channel
 	unsigned int srcVChan; //!< the channel of the source's V channel
-
 	
 	std::vector<cmap_t*> tmaps; //!< list of threshold maps so you can segment the same source different ways
 	std::vector<std::string> tmapNames; //!< filename of each tmap;
@@ -138,10 +136,10 @@ private:
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:48 $
+ * $Date: 2004/02/18 21:13:32 $
  */
 
 #endif
