@@ -26,7 +26,7 @@ StartupBehavior::SetupModeSwitch() {
 		BehaviorSwitchControlBase::BehaviorGroup * bg = new BehaviorSwitchControlBase::BehaviorGroup();
 
 		//put behaviors here:
-		if(state->robotDesign&WorldState::ERS210Mask) //this one only really works on the 210
+		if(state->robotDesign&(WorldState::ERS210Mask|WorldState::ERS7Mask)) //this one only really works on the 210 or 7
 			addItem(new BehaviorSwitchControl<AlanBehavior>("AlanBehavior",bg,false));
 		addItem(new BehaviorSwitchControl<FollowHeadBehavior>("FollowHeadBehavior",bg,false));
 		addItem(new BehaviorSwitchControl<SoundTestBehavior>("SoundTestBehavior",bg,false));
