@@ -40,22 +40,14 @@ StartupBehavior::initVision() {
 	unsigned int numSystemLayers=3;
 
 	defRawCameraGenerator = new RawCameraGenerator(numSystemLayers,numLayers,EventBase::visOFbkEGID,0,visRawCameraSID);
-	defRawCameraGenerator->DoStart();
-	spawned.push_back(defRawCameraGenerator);
 
 	defInterleavedYUVGenerator = new InterleavedYUVGenerator(EventBase::visRawCameraEGID,visRawCameraSID,visInterleaveSID,RawCameraGenerator::CHAN_Y,RawCameraGenerator::CHAN_U,RawCameraGenerator::CHAN_V);
-	defInterleavedYUVGenerator->DoStart();
-	spawned.push_back(defInterleavedYUVGenerator);
 
 	defColorJPEGGenerator = new JPEGGenerator(EventBase::visInterleaveEGID,visInterleaveSID,visColorJPEGSID,JPEGGenerator::SRC_AUTO);
-	defColorJPEGGenerator->DoStart();
 	defColorJPEGGenerator->setName("ColorJPEGGenerator");
-	spawned.push_back(defColorJPEGGenerator);
 
 	defGrayscaleJPEGGenerator = new JPEGGenerator(EventBase::visRawCameraEGID,visRawCameraSID,visGrayscaleJPEGSID,JPEGGenerator::SRC_AUTO);
-	defGrayscaleJPEGGenerator->DoStart();
 	defGrayscaleJPEGGenerator->setName("GrayscaleJPEGGenerator");
-	spawned.push_back(defGrayscaleJPEGGenerator);
 
 	// the hardware level CDT generator allows faster, but less flexible
 	// segmenting it still needs a little work though before it can be
@@ -66,18 +58,10 @@ StartupBehavior::initVision() {
 	segcol->loadColorInfo(config->vision.colors);
 	for(unsigned int i=0; i<config->vision.thresh.size(); i++)
 		segcol->loadThresholdMap(config->vision.thresh[i]);
-	if(config->vision.colors!="" && config->vision.thresh.size()>0) {
-		defSegmentedColorGenerator->DoStart();
-		spawned.push_back(defSegmentedColorGenerator);
-	}
 
 	defRLEGenerator = new RLEGenerator(EventBase::visSegmentEGID,visSegmentSID,visRLESID);
-	defRLEGenerator->DoStart();
-	spawned.push_back(defRLEGenerator);
 	
 	defRegionGenerator = new RegionGenerator(EventBase::visRLEEGID,visRLESID,visRegionSID);
-	defRegionGenerator->DoStart();
-	spawned.push_back(defRegionGenerator);
 	
 	// for lack of a better idea, the object recognizers below will all
 	// use the config->vision.rlecam_channel for picking the threshold
@@ -100,22 +84,16 @@ StartupBehavior::initVision() {
 	if(pinkIdx!=-1U) {
 		pball = new BallDetectionGenerator(EventBase::visRegionEGID,visRegionSID,visPinkBallSID,pinkIdx,threshChan,noiseFiltering,confidenceThreshold);
 		pball->setName("PinkBallDetectionGenerator");
-		pball->DoStart();
-		spawned.push_back(pball);
 	}
 	unsigned int blueIdx=segcol->getColorIndex("blue");
 	if(blueIdx!=-1U) {
 		bball = new BallDetectionGenerator(EventBase::visRegionEGID,visRegionSID,visBlueBallSID,blueIdx,threshChan,noiseFiltering,confidenceThreshold);
-		pball->setName("BlueBallDetectionGenerator");
-		bball->DoStart();
-		spawned.push_back(bball);
+		bball->setName("BlueBallDetectionGenerator");
 	}
 	unsigned int skinIdx=segcol->getColorIndex("brown");
 	if(skinIdx!=-1U) {
 		handball = new BallDetectionGenerator(EventBase::visRegionEGID,visRegionSID,visHandSID,skinIdx,threshChan,noiseFiltering,confidenceThreshold);
-		pball->setName("HandBallDetectionGenerator");
-		handball->DoStart();
-		spawned.push_back(handball);
+		handball->setName("HandBallDetectionGenerator");
 	}
 }
 
@@ -124,16 +102,19 @@ StartupBehavior::SetupVision() {
 	addItem(new ControlBase("Vision Pipeline","Start/Stop stages of the vision pipeline"));
 	startSubMenu();
 	{ 
-		addItem(new BehaviorSwitchControlBase(defRawCameraGenerator));
-		addItem(new BehaviorSwitchControlBase(defInterleavedYUVGenerator));
-		addItem(new BehaviorSwitchControlBase(defColorJPEGGenerator));
-		addItem(new BehaviorSwitchControlBase(defGrayscaleJPEGGenerator));
-		addItem(new BehaviorSwitchControlBase(defSegmentedColorGenerator));
-		addItem(new BehaviorSwitchControlBase(defRLEGenerator));
-		addItem(new BehaviorSwitchControlBase(defRegionGenerator));
-		addItem(new BehaviorSwitchControlBase(pball));
-		addItem(new BehaviorSwitchControlBase(bball));
-		addItem(new BehaviorSwitchControlBase(handball));
+		addItem((new BehaviorSwitchControlBase(defRawCameraGenerator))->start());
+		addItem((new BehaviorSwitchControlBase(defInterleavedYUVGenerator))->start());
+		addItem((new BehaviorSwitchControlBase(defColorJPEGGenerator))->start());
+		addItem((new BehaviorSwitchControlBase(defGrayscaleJPEGGenerator))->start());
+		if(config->vision.colors!="" && config->vision.thresh.size()>0)
+			addItem((new BehaviorSwitchControlBase(defSegmentedColorGenerator))->start());
+		else
+			addItem(new BehaviorSwitchControlBase(defSegmentedColorGenerator));
+		addItem((new BehaviorSwitchControlBase(defRLEGenerator))->start());
+		addItem((new BehaviorSwitchControlBase(defRegionGenerator))->start());
+		addItem((new BehaviorSwitchControlBase(pball))->start());
+		addItem((new BehaviorSwitchControlBase(bball))->start());
+		addItem((new BehaviorSwitchControlBase(handball))->start());
 	}
 	return endSubMenu();
 }
