@@ -9,10 +9,10 @@
  * @author PA Gov. School for the Sciences 2003 Team Project - Motion group: Haoqian Chen, Yantian Martin, Jon Stahlman (creators)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_0_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/01/16 05:14:39 $
+ * $Date: 2004/02/26 01:03:00 $
  */
 
 #include "StartupBehavior.h"
@@ -126,7 +126,7 @@ StartupBehavior::SetupWalkEdit() {
 		startSubMenu();
 		{ 
 			addItem(new WalkCalibration());
-			addItem(new LoadCalibration<3,11>(walker->getWalkMC()->getCP().f_calibration,walker->getWalkMC()->getCP().b_calibration));
+			addItem(new LoadCalibration(&walker->getWalkMC()->getCP()));
 			addItem(new ValueEditControl<float>("forward max_accel",&walker->getWalkMC()->getCP().max_accel[WalkMC::CalibrationParam::forward]));
 			addItem(new ValueEditControl<float>("reverse max_accel",&walker->getWalkMC()->getCP().max_accel[WalkMC::CalibrationParam::reverse]));
 			addItem(new ValueEditControl<float>("strafe max_accel",&walker->getWalkMC()->getCP().max_accel[WalkMC::CalibrationParam::strafe]));
