@@ -106,7 +106,7 @@ public class VisionPanel extends JPanel implements VisionUpdatedListener {
 			float curasp=sz.width/(float)sz.height;
 			float tgtasp=getAspectRatio();
 			if(tgtasp<0)
-				tgtasp=curasp;
+				tgtasp=_image.getWidth()/(float)_image.getHeight();
 			if(curasp>tgtasp) {
 				int width=(int)(sz.height*tgtasp);
 				drawImage(graphics,_image, (sz.width-width)/2, 0, width, sz.height);
