@@ -96,9 +96,9 @@ public class ImageShow extends JFrame implements KeyListener {
       curimg--;
       if (curimg<0) curimg+=imglist.length;
 			if(isRGB)
-				imageData.loadRGBFileAsYUV(imglist[curimg]);
+				imageData.loadRGBFileAsRGB(imglist[curimg]);
 			else
-				imageData.loadYUVFileAsYUV(imglist[curimg]);
+				imageData.loadYUVFileAsRGB(imglist[curimg]);
       int[] data=imageData.getPixels();
       showImage(data, tmap, imageData.image_width, imageData.image_height);
     } else if (e.getKeyCode()==KeyEvent.VK_RIGHT ||
@@ -109,9 +109,9 @@ public class ImageShow extends JFrame implements KeyListener {
       curimg++;
       if (curimg>=imglist.length) curimg-=imglist.length;
 			if(isRGB)
-				imageData.loadRGBFileAsYUV(imglist[curimg]);
+				imageData.loadRGBFileAsRGB(imglist[curimg]);
 			else
-				imageData.loadYUVFileAsYUV(imglist[curimg]);
+				imageData.loadYUVFileAsRGB(imglist[curimg]);
       int[] data=imageData.getPixels();
       showImage(data, tmap, imageData.image_width, imageData.image_height);
     }
